#!/bin/sh
#
# Install script
# usage: ./install.sh
#


LANG=C
export LANG
HOME_ORG=$HOME

wlabel=stor2rrd
WLABEL=STOR2RRD

wlabel_company="xorux"
WLABEL_COMPANY="XORUX"
wlabel_domain="com"
wlabel_docu=""
wlabel_logo_only=""

if [ -f wlabel.txt ]; then
  wlabel=`cat wlabel.txt| tail -1`
  WLABEL=`echo $wlabel| tr '[:lower:]' '[:upper:]'`
fi

if [ "$WLABEL" = "BREAKPOINT" ]; then
  # just do a record in etc/.magic, nothing else, return wlabel to original
  wlabel_logo_only=$WLABEL
  wlabel=stor2rrd
  WLABEL=STOR2RRD
fi

if [ "$WLABEL" = "CIRO" ]; then
  wlabel_company="cutaway"
  WLABEL_COMPANY="Cutaway"
  wlabel_domain="it"
  wlabel_docu="documentation-ciro"
fi

if [ ! "$1"x = "x" ]; then
  if [ "$1" = "wrap" ]; then
    # create a package, internall usage only
    ver=`grep "version=" dist_storage/etc/$wlabel.cfg|sed 's/version=//g'`
    if [ "$ver"x = "x" ]; then
      echo "Something is wroing, cannot find the version"
      exit 1
    fi
    if [ -f $wlabel.tar.Z ]; then
      echo "removing $wlabel.tar.Z"
      rm $wlabel.tar.Z
    fi
    if [ -f $wlabel.tar ]; then
      echo "removing $wlabel.tar"
      rm $wlabel.tar
    fi
    tar cvf $wlabel.tar dist_storage
    compress $wlabel.tar
    if [ -f $wlabel.tar.Z ]; then
      echo "removing dist"
      rm -r dist_storage
    fi
    echo ""
    echo "$ver has been created"
    echo ""
    exit
  fi
fi

os_aix=` uname -s|egrep "^AIX$"|wc -l|sed 's/ //g'`

# test if "ed" command does not exist, it might happen especially on some Linux distros
ed << END 2>/dev/null 1>&2
q
END
if [ $? -gt 0 ]; then
  echo "ERROR: "ed" command does not seem to be installed or in $PATH"
  echo "Linux under root account: yum install ed"
  echo "Exiting ..."
  exit 1
fi
echo "1+1"|bc 2>/dev/null 1>&2
if [ $? -gt 0 ]; then
  echo "ERROR: "bc" command does not seem to be installed or in $PATH"
  echo "Linux under root account: yum install bc"
  echo "Exiting ..."
  exit 1
fi


umask 0022 
ID=`id -un`

echo "$WLABEL installation under user: \"$ID\""
echo " make sure it is realy the user which should own it"
echo ""
HOME1="$HOME/$wlabel"
if [ -f "$HOME/.${wlabel}_home" ]; then
  HOME1=`cat "$HOME/.${wlabel}_home"`
fi
echo "Where $WLABEL will be installed [$HOME1]:"
read HOMELPAR

if [ "$HOMELPAR"x = "x" ]; then
    HOMELPAR="$HOME1"
fi

if [ -f $HOMELPAR/bin/storage.pl ]; then
  echo "$WLABEL instance already exists there, use update.sh script for the update"
  exit 0
fi

# creating ssh keys if they do not exist, needed for SVC/Storwize
echo "" |ssh-keygen -t dsa -P "" 2>/dev/null 1>/dev/null

#echo "What user will be used for storage access: [$ID]"
#read id_new

#if [ ! "$id_new"x = "x" ]; then
#   id=$id_new 
#fi

if [ "$HOMELPAR"x = "x" ]; then
  HOMELPAR=$HOME/$wlabel
fi

if [ ! -d "$HOMELPAR" ]; then
  echo "Creating $HOMELPAR"
  mkdir "$HOMELPAR"
  if [ ! $? -eq 0 ]; then
    echo "Error during creation of $HOMELPAR, exiting ..."
    exit 0
  fi
fi

touch test
if [ ! $? -eq 0 ]; then
  p=`pwd`
  echo "Actual user does not have rights to create files in actual directory: $p "
  echo "Fix it and re-run installation"
  exit 1
fi
rm -f test

if [ -f $wlabel.tar.Z ]; then
  which uncompress >/dev/null 2>&1 
  if [ $? -eq 0 ]; then 
     uncompress -f $wlabel.tar.Z 
  else 
     which gunzip >/dev/null 2>&1 
     if [ $? -eq 0 ]; then 
       gunzip -f $wlabel.tar.Z 
     else 
       echo "Could not locate uncompress or gunzip commands. exiting" 
       exit 
     fi 
  fi 
fi

chown $ID $HOMELPAR 
if [ ! $? -eq 0 ]; then
  echo "Problem with ownership of $HOMELPAR"
  echo "Fix it and run it again : chown  $ID $HOMELPAR"
  exit 0
fi

echo "Extracting distribution"
tar xf $wlabel.tar

echo "Copy distribution to the target location: $HOMELPAR"
# mv dist_storage/* $HOMELPAR/# tar must be used due to Docker
apath=`pwd`
cd dist_storage
tar cf - . | (cd $HOMELPAR/; tar xf - )
cd $apath


if [ $os_aix -gt 0 ]; then
  # extract perl lib for https REST API support (LWP 6.06)
  if [ -f perl_aix_ssl.tar.Z ]; then
    uncompress -f perl_aix_ssl.tar.Z
  fi
  if [ -f perl_aix_ssl.tar ]; then
    tar xf perl_aix_ssl.tar
    cp -R lib $HOMELPAR/
  else
    echo "ERROR during: uncompress -f perl_aix_ssl.tar.Z : install it manually"
    echo "  uncompress -f perl_aix_ssl.tar.Z; cd $HOMELPAR/; tar xvf perl_aix_ssl.tar"
  fi
fi

if [ -f version.txt ]; then
  version=`cat version.txt|tail -1|sed 's/ .*//'`
fi

COLLECTOR=0
if [ ! -f "$HOMELPAR/etc/.magic" -a -f "$HOMELPAR/etc/.magic-install" ]; then
  mv "$HOMELPAR/etc/.magic-install" "$HOMELPAR/etc/.magic"
  chmod 644 "$HOMELPAR/etc/.magic"
  . "$HOMELPAR/etc/.magic"
  if [ ! "$DO_NOT_SAVE_DATA"x = "x" ]; then
    if [ $DO_NOT_SAVE_DATA -eq 1 ]; then
      COLLECTOR=1
    fi
  fi
fi


if [ $COLLECTOR -eq 0 ]; then
  #  put WEB files immediately after the upgrade to do not have to wait for the end of upgrade
  echo "Copy GUI files : $HOMELPAR/www"
  cp $HOMELPAR/html/*html $HOMELPAR/www
  cp $HOMELPAR/html/*ico $HOMELPAR/www
  cp $HOMELPAR/html/*png $HOMELPAR/www

  cd $HOMELPAR/html
  tar cf - jquery | (cd $HOMELPAR/www; tar xf - )
  tar cf - css    | (cd $HOMELPAR/www; tar xf - )
  #cd - >/dev/null
  if [ ! -f "$HOMELPAR/tmp/menu.txt" -a -f "$HOMELPAR/html/menu_default.txt" ]; then
    #place default menu.txt
    cp $HOMELPAR/html/menu_default.txt $HOMELPAR/tmp/menu.txt
  fi
  chmod -R 755 $HOMELPAR/html # must be due tue subdirs jquery, images ...
fi

# White labeling stuff

if [ ! "$WLABEL" = "STOR2RRD" ]; then
 # cgi-bin for white labeling stuff, it must be before White Label cleaning!!!
 if [ ! -d $HOMELPAR/$wlabel-cgi -a -d $HOMELPAR/stor2rrd-cgi ]; then
   mv $HOMELPAR/stor2rrd-cgi $HOMELPAR/$wlabel-cgi
 fi
 if [ -d $HOMELPAR/$wlabel-cgi -a -d $HOMELPAR/stor2rrd-cgi ]; then
   mv $HOMELPAR/stor2rrd-cgi/* $HOMELPAR/$wlabel-cgi
   mv $HOMELPAR/$wlabel-cgi/stor2rrd-cgi.sh $HOMELPAR/$wlabel-cgi/$wlabel-cgi.sh
   rm -rf $HOMELPAR/stor2rrd-cgi/
 fi
fi

#
# White Label cleaning
#

if [ ! "$WLABEL" = "STOR2RRD" ]; then
  rm -f $HOMELPAR/README
  if [ -f $HOMELPAR/bin/check_stor2rrd ]; then
    mv $HOMELPAR/bin/check_stor2rrd $HOMELPAR/bin/check_$wlabel
  fi

for i in $HOMELPAR/html/*.html $HOMELPAR/html/jquery/main.js $HOMELPAR/bin/*
do
  ed $i << EOF >/dev/null 2>&1
g/logo-stor2rrd/s/logo-stor2rrd/logo-$wlabel/g
g/STOR2RRD HOME/s/STOR2RRD HOME/$WLABEL HOME/g
g/STOR2RRD website/s/STOR2RRD website/$WLABEL website/g
g/STOR2RRD cookies/s/STOR2RRD cookies/$WLABEL cookies/g
g/STOR2RRD edition/s/STOR2RRD edition/$WLABEL edition/g
g/STOR2RRD version/s/STOR2RRD version/$WLABEL version/g
g/http:\/\/www\.stor2rrd\.com\/.*.html/s/http:\/\/www\.stor2rrd\.com\/.*.html/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/http:\/\/www\.stor2rrd\.com\/.*.htm/s/http:\/\/www\.stor2rrd\.com\/.*.htm/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/http:\/\/www\.stor2rrd\.com\/.*.pdf/s/http:\/\/www\.stor2rrd\.com\/.*.pdf/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/http:\/\/www\.stor2rrd\.com\/.*.csv/s/http:\/\/www\.stor2rrd\.com\/.*.csv/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/http:\/\/www\.stor2rrd\.com\/.*.zip/s/http:\/\/www\.stor2rrd\.com\/.*.zip/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.html/s/https:\/\/www\.stor2rrd\.com\/.*.html/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.htm/s/https:\/\/www\.stor2rrd\.com\/.*.htm/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.pdf/s/https:\/\/www\.stor2rrd\.com\/.*.pdf/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.csv/s/https:\/\/www\.stor2rrd\.com\/.*.csv/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.zip/s/https:\/\/www\.stor2rrd\.com\/.*.zip/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
w
q
EOF
done

for i in $HOMELPAR/html/jquery/main.js
do
  ed $i << EOF >/dev/null 2>&1
g/www.xorux.com/s/www.xorux.com/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/>XORUX</s/>XORUX</>$WLABEL_COMPANY</g
w
q
EOF
done

for i in $HOMELPAR/html/jquery/main.js
do
  ed $i << EOF >/dev/null 2>&1
g/www.xorux.com/s/www.xorux.com/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/www.stor2rrd.com/s/www.stor2rrd.com/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/>XORUX</s/>XORUX</>$WLABEL</g
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
w
q
EOF
done

for i in $HOMELPAR/bin/AlertStor2rrd.pm
do
  ed $i << EOF >/dev/null 2>&1
g/stor2rrd-alert-/s/stor2rrd-alert-/$wlabel-alert-</g
w
q
EOF
done


for i in $HOMELPAR/$wlabel-cgi/genpdf.sh $HOMELPAR/$wlabel-cgi/heatmapcfg.sh
do
  ed $i << EOF >/dev/null 2>&1
g/APPNAME="stor2rrd"/s/APPNAME="stor2rrd"/APPNAME="$wlabel"/g
w
q
EOF
done

for i in $HOMELPAR/*.sh
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
w
q
EOF
done

for i in $HOMELPAR/bin/*.sh
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/stor2rrd-realt-error/s/stor2rrd-realt-error/$wlabel-realt-error/g
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
g/stor2rrd-cgi\.sh/s/stor2rrd-cgi\.sh/$wlabel-cgi\.sh/g
w
q
EOF
done

for i in $HOMELPAR/$wlabel-cgi/*.sh
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/stor2rrd-realt-error/s/stor2rrd-realt-error/$wlabel-realt-error/g
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
g/stor2rrd-cgi\.sh/s/stor2rrd-cgi\.sh/$wlabel-cgi\.sh/g
w
q
EOF
done

for i in $HOMELPAR/html/* $HOMELPAR/etc/links.json
do
  ed $i << EOF >/dev/null 2>&1
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
g/stor2rrd-cgi\.sh//s/stor2rrd-cgi\.sh//$wlabel-cgi\.sh//g
w
q
EOF
done

for i in $HOMELPAR/bin/*.pl
do
  ed $i << EOF >/dev/null 2>&1
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
g/www\.stor2rrd\.com/s/www\.stor2rrd\.com/www\.$wlabel\.com/g
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/>STOR2RRD</s/>STOR2RRD</>$WLABEL</g
g/TITLE>STOR2RRD</s/TITLE>STOR2RRD</TITLE>$WLABEL</g
g/title>STOR2RRD</s/title>STOR2RRD</title>$WLABEL</g
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
w
q
EOF
done

for i in $HOMELPAR/bin/*
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD_HOME/s/STOR2RRD_HOME/$WLABEL_HOME/g
g/LPAR2RRD_HOME/s/LPAR2RRD_HOME/$WLABEL_HOME/g
g/check_stor2rrd/s/check_stor2rrd/check_$wlabel/g
w
q
EOF
done

for i in $HOMELPAR/bin/*.pm
do
  ed $i << EOF >/dev/null 2>&1
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
g/www\.stor2rrd\.com/s/www\.stor2rrd\.com/www\.$wlabel\.com/g
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/TITLE>STOR2RRD</s/TITLE>STOR2RRD</TITLE>$WLABEL</g
w
q
EOF
done

for i in $HOMELPAR/etc/storage-list.cfg*
do
  ed $i << EOF >/dev/null 2>&1
g/#  --> Check http/s/#  --> Check http.*$//g
w
q
EOF
done

for i in $HOMELPAR/etc/web_config/*
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
w
q
EOF
done

ed $HOMELPAR/html/support_logs.html << EOF >/dev/null 2>&1
g/stor2rrd/s/stor2rrd/$wlabel/g
w
q
EOF


fi

if [ `grep $WLABEL $HOMELPAR/etc/.magic 2>/dev/null | wc -l | sed 's/ //g'` -eq 0 ]; then
  if [ ! "$WLABEL" = "STOR2RRD" ]; then
    # add wlabel
    echo "WLABEL=$WLABEL" >> $HOMELPAR/etc/.magic
    echo "export WLABEL" >> $HOMELPAR/etc/.magic
  fi
  if [ "$wlabel_logo_only" = "BREAKPOINT" ]; then
    # add wlabel
    echo "WLABEL=BREAKPOINT" >> $HOMELPAR/etc/.magic
    echo "export WLABEL" >> $HOMELPAR/etc/.magic
  fi
fi

######################## W labeling end

chown -R $ID $HOMELPAR 2>&1| egrep -v "lost+found"
chmod 755 $HOMELPAR
chmod 666 $HOMELPAR/logs/error.log
chmod 755 $HOMELPAR/data
chmod 755 $HOMELPAR/lib
chmod 755 $HOMELPAR/MIBs
chmod 755 $HOMELPAR/www
chmod 755 $HOMELPAR/bin
chmod 755 $HOMELPAR/etc
chmod 755 $HOMELPAR/logs
chmod 755 $HOMELPAR/dbschema
if [ ! -d $HOMELPAR/tmp ]; then
  mkdir $HOMELPAR/tmp
fi
if [ "$VM_IMAGE"x = "x" ]; then
  chmod 777 $HOMELPAR/tmp  # due to Xormon which needs to save temp files there
else
  chmod 755 $HOMELPAR/tmp  # not necessary on the image
fi
chmod -R 755 $HOMELPAR/$wlabel-cgi
chmod -R o+r $HOMELPAR/data
chmod -R o+r $HOMELPAR/MIBs
chmod -R o+x $HOMELPAR/data
chmod -R o+r $HOMELPAR/www
chmod -R o+x $HOMELPAR/www
chmod 644 $HOMELPAR/dbschema/*
chmod 755 $HOMELPAR/bin/*.pl
chmod 755 $HOMELPAR/bin/*.py
chmod 755 $HOMELPAR/bin/*.pm
chmod 755 $HOMELPAR/bin/*.sh
chmod 755 $HOMELPAR/*.sh
chmod 644 $HOMELPAR/etc/*.cfg
chmod 644 $HOMELPAR/MIBs/*

if [ "$VM_IMAGE"x = "x" -a ! "$wlabel" = "stor2rrd" ]; then
  mv $HOMELPAR/etc/stor2rrd.cfg $HOMELPAR/etc/$wlabel.cfg
fi

if [ "$VM_IMAGE"x = "x" ]; then
  chmod 644 $HOMELPAR/etc/storage-list.cfg # passwords might be inside!
else
  chmod 600 $HOMELPAR/etc/storage-list.cfg # passwords might be inside!
fi

if [ ! -h $HOMELPAR/logs/error-cgi.log ]; then
  ln -s /var/tmp/$wlabel-realt-error.log $HOMELPAR/logs/error-cgi.log 2>/dev/null
fi

if [ ! -d "$HOMELPAR/etc/web_config" ]; then
  mkdir "$HOMELPAR/etc/web_config"
fi
if [ "$VM_IMAGE"x = "x" ]; then
  chmod 777 "$HOMELPAR/etc/web_config"
  chmod 777 "$HOMELPAR/reports"
else
  chmod 755 "$HOMELPAR/etc/web_config"
  chmod 755 "$HOMELPAR/reports"
fi

if [ ! -f "$HOMELPAR/etc/web_config/htusers.cfg" ]; then
  echo 'admin:$apr1$CSoXefyw$wGe9K7Ld5ClOEozE4zC.T1' >  $HOMELPAR/etc/web_config/htusers.cfg
  if [ "$VM_IMAGE"x = "x" ]; then
    chmod 666 $HOMELPAR/etc/web_config/htusers.cfg
  else
    chmod 600 $HOMELPAR/etc/web_config/htusers.cfg
  fi
fi


if [ ! -f $HOMELPAR/etc/heatmap-color.cfg ]; then
  mv $HOMELPAR/etc/heatmap-color.cfg-default  $HOMELPAR/etc/heatmap-color.cfg
fi

export PATH=$PATH:/opt/freeware/bin
rrd=`which   rrdtool|awk '{print $1}'|wc -w`
if [ $rrd -eq 0 ]; then
  if [ -f /opt/freeware/bin/rrdtool ]; then
    rrd="/opt/freeware/bin/rrdtool"
  else
    echo ""
    echo "Warning: RRDTool has not been found in \$PATH, using RRDTOOL=/usr/bin/rrdtool"
    echo "         assure it is ok, if not then edit $HOMELPAR/etc/$wlabel.cfg and change it"
    echo ""
    rrd="/usr/bin/rrdtool"
  fi
else
  rrd=`which   rrdtool|awk '{print $1}'`
fi

per=`which   perl|awk '{print $1}'|wc -w`
if [ $per -eq 0 ]; then
  echo ""
  echo "Warning: Perl has not been found in \$PATH, placing /usr/bin/perl"
  echo "         assure it is ok, if not then edit $HOMELPAR/etc/$wlabel.cfg and change it"
  echo ""
  per="/usr/bin/perl"
else
  per=`which   perl|awk '{print $1}'`
fi

if [ ! "$CUSTOM_PERL_INTERPRETER"x = "x" -a -f "$CUSTOM_PERL_INTERPRETER" ]; then
  per="$CUSTOM_PERL_INTERPRETER"
fi

# replace path for actual one in config files


HOMELPAR_slash=`echo $HOMELPAR|sed 's/\//\\\\\\//g'`
HOME_slash=`echo $HOME|sed 's/\//\\\\\\//g'`
rrd_slash=`echo $rrd|sed 's/\//\\\\\\//g'`
per_slash=`echo $per|sed 's/\//\\\\\\//g'`
bit64=`file $per 2>/dev/null| grep 64-bit| wc -l | sed 's/ //g'`

# add actual paths
PERL5LIB=/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi:/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi:/usr/lib64/perl5:/opt/freeware/lib/perl/5.8.8:/opt/freeware/lib/perl/5.8.0:/usr/opt/perl5/lib/site_perl/5.8.2:/usr/lib/perl5/vendor_perl/5.8.5:/usr/share/perl5:/usr/lib/perl5:/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi:/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi:/usr/lib64/perl5/vendor_perl:/usr/lib/perl5/vendor_perl

# add actual paths
# This /usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi must be befor /usr/opt/perl5/lib/site_perl/5.10.1/aix-thread-multi when is /opt/freeware/bin/perl used otherwisi is usede wrong SSLeay.so
# (https.pm is not found then)
p_ver=`$per -e 'print "$]\n"'`
if [ "$per" = "/opt/freeware/bin/perl" -a $p_ver = "5.008008" ]; then
  # AIX, excluded /usr/opt/perl5/lib64/5.28.1 which causing a problem
  PPATH="/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi
/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0/ppc-aix-thread-multi
/opt/freeware/lib64/perl5
/opt/freeware/lib/perl5
/opt/freeware/lib/perl
/usr/opt/perl5/lib/site_perl
/opt/freeware/lib/perl5/vendor_perl/5.8.8
/usr/share/perl5/vendor_perl
/opt/csw/share/perl/csw
/opt/csw/lib/perl/site_perl
/usr/opt/perl5/lib/site_perl/5.10.1/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.28.0/ppc-aix-thread-multi
/opt/freeware/lib/perl5/site_perl
/usr/lib64/perl5/vendor_perl
/usr/opt/perl5/lib/site_perl/5.10.1
/usr/opt/perl5/lib/site_perl/5.28.1
/usr/opt/perl5/lib64/site_perl"
else
  if [ $bit64 -eq 0 ]; then
    PPATH="/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi
/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0/ppc-aix-thread-multi
/opt/freeware/lib/perl5
/opt/freeware/lib/perl
/usr/opt/perl5/lib/site_perl
/usr/lib/perl5/vendor_perl
/opt/freeware/lib/perl5/vendor_perl/5.8.8
/opt/freeware/lib/perl5/vendor_perl
/usr/share/perl5/vendor_perl
/opt/csw/share/perl/csw
/opt/csw/lib/perl/site_perl
/usr/opt/perl5/lib/site_perl/5.10.1/aix-thread-multi
/usr/opt/perl5/lib/site_perl/
/opt/freeware/lib/perl5/site_perl/5.28.0/ppc-aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0
/opt/freeware/lib/perl5/site_perl/
/usr/opt/perl5/lib
/usr/opt/perl5/lib/site_perl/5.10.1
/usr/opt/perl5/lib/site_perl/5.28.1
/opt/freeware/lib/perl5/5.30/vendor_perl"
  else
    PPATH="/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi
/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0/ppc-aix-thread-multi
/opt/freeware/lib64/perl5
/opt/freeware/lib/perl5
/opt/freeware/lib/perl
/usr/opt/perl5/lib/site_perl
/usr/lib/perl5/vendor_perl
/opt/freeware/lib/perl5/vendor_perl/5.8.8
/opt/freeware/lib/perl5/vendor_perl
/usr/share/perl5/vendor_perl
/opt/csw/share/perl/csw
/opt/csw/lib/perl/site_perl
/usr/opt/perl5/lib/site_perl/5.10.1/aix-thread-multi
/usr/opt/perl5/lib/site_perl/
/opt/freeware/lib/perl5/site_perl/5.28.0/ppc-aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0
/opt/freeware/lib/perl5/site_perl/
/usr/opt/perl5/lib64/5.28.1
/usr/opt/perl5/lib64/5.28.0
/usr/opt/perl5/lib64
/usr/opt/perl5/lib
/usr/lib64/perl5/vendor_perl
/usr/opt/perl5/lib64/site_perl
/usr/opt/perl5/lib64/site_perl/5.28.1
/usr/opt/perl5/lib64/site_perl/5.28.1/aix-thread-multi-64all
/usr/opt/perl5/lib/site_perl/5.10.1
/usr/opt/perl5/lib/site_perl/5.28.1
/opt/freeware/lib/perl5/5.30/vendor_perl
/opt/freeware/lib64/perl5/5.30/vendor_perl
/usr/opt/perl5/lib64/site_perl"
  fi
fi

# /opt/csw/share/perl/csw is necessary on Solaris

perl_version=`$per -v| grep "This is perl"| sed -e 's/^.* (v//' -e 's/) .*//' -e 's/^.* v//' -e 's/ .*//'`
perl_subversion=`$per -v| grep "This is perl"| sed -e 's/^.* (v//' -e 's/) .*//' -e 's/^.* v//' -e 's/ .*//' -e 's/\.[0-9][0-9]$//' -e 's/\.[0-9]$//' `

PLIB=`for ppath in $PPATH
do
  echo $PERL5LIB|grep "$ppath/$perl_version"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_version" ]; then
    echo "$ppath/$perl_version"
    echo "$ppath/$perl_version/vendor_perl"
    if [ $os_aix -eq 1 ]; then
      if [ $bit64 -eq 0 ]; then
        echo "$ppath/$perl_version/ppc-aix-thread-multi"
        echo "$ppath/$perl_version/aix-thread-multi"
      else
        echo "$ppath/$perl_version/aix-thread-multi-64all" # this must be behind 32bit!
      fi
    fi
  else
    echo $PERL5LIB|grep "$ppath"  >/dev/null
    if [ ! $? -eq 0  -a -d "$ppath" ]; then
      echo "$ppath"
    fi
  fi

  echo $PERL5LIB|grep "$ppath/$perl_version/aix-thread-multi"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_version/aix-thread-multi" ]; then
    echo "$ppath/$perl_version/aix-thread-multi"
  fi

  echo $PERL5LIB|grep "$ppath/$perl_version/ppc-aix-thread-multi"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_version/ppc-aix-thread-multi" ]; then
    echo "$ppath/$perl_version/ppc-aix-thread-multi"
  fi

  echo $PERL5LIB|grep "$ppath/$perl_version/vendor_perl"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_version/vendor_perl" ]; then
    echo "$ppath/$perl_version/vendor_perl"
  fi

  echo $PERL5LIB|grep "$ppath/$perl_subversion"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_subversion" ]; then
    echo "$ppath/$perl_subversion"
    echo "$ppath/$perl_subversion/vendor_perl"
    if [ $os_aix -eq 1 ]; then
      if [ $bit64 -eq 0 ]; then 
        echo "$ppath/$perl_subversion/ppc-aix-thread-multi"
        echo "$ppath/$perl_subversion/aix-thread-multi"
      else
        echo "$ppath/$perl_subversion/aix-thread-multi-64all" # this must be behind 32bit!
      fi 
    fi
  else
    echo $PERL5LIB|grep "$ppath"  >/dev/null
    if [ ! $? -eq 0  -a -d "$ppath" ]; then
      echo "$ppath"
    fi
  fi

  echo $PERL5LIB|grep "$ppath/$perl_subversion/aix-thread-multi"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_subversion/aix-thread-multi" ]; then
    echo "$ppath/$perl_subversion/aix-thread-multi"
  fi

  echo $PERL5LIB|grep "$ppath/$perl_subversion/ppc-aix-thread-multi"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_subversion/ppc-aix-thread-multi" ]; then
    echo "$ppath/$perl_subversion/ppc-aix-thread-multi"
  fi

  echo $PERL5LIB|grep "$ppath/$perl_subversion/vendor_perl"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_subversion/vendor_perl" ]; then
    echo "$ppath/$perl_subversion/vendor_perl"
  fi

done|xargs|sed 's/ /:/g'`


if [ $os_aix -gt 0 ]; then
  # AIX place $HOMELPAR/lib on its start due to LWP https modules
  perl5lib="$HOMELPAR/bin:$HOMELPAR/lib:$PLIB:$PERL5LIB"
else
  perl5lib="$HOMELPAR/bin:$PLIB:$PERL5LIB:$HOMELPAR/lib"
fi

# Clean up PERL5LIB, place only existing dirs
PERL5LIB_new=""
for lib_path in `echo $perl5lib| sed 's/:/ /g'`
do
  if [ -d "$lib_path" ]; then
    if [ `echo "$PERL5LIB_new" | egrep "$lib_path:|$lib_path$" | wc -l | sed 's/ //g'` -eq 1 ]; then
      continue
    fi
    if [ "$PERL5LIB_new"x = "x" ]; then
      PERL5LIB_new=$lib_path
    else
      PERL5LIB_new=$PERL5LIB_new:$lib_path
    fi
  fi
done

# AIX: always keep this in PERL5LIB
# /opt/freeware/lib/perl/5.8.8:/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi:/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi
if [ $os_aix -eq 1 ]; then
  if [ `echo "$PERL5LIB_new"|grep "/opt/freeware/lib/perl/5.8.8" | wc -l` -eq 0 ]; then
    PERL5LIB_new="$PERL5LIB_new:/opt/freeware/lib/perl/5.8.8"
  fi
  if [ `echo "$PERL5LIB_new"|grep "/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi" | wc -l` -eq 0 ]; then
    PERL5LIB_new="$PERL5LIB_new:/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi"
  fi
  if [ `echo "$PERL5LIB_new"|grep "/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi" | wc -l` -eq 0 ]; then
    PERL5LIB_new="$PERL5LIB_new:/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi"
  fi
fi

# Solaris: always keep this in PERL5LIB
# /opt/csw/share/perl/csw /opt/csw/lib/perl/site_perl
if [ `uname|grep SunOS|wc -l|  sed 's/ //g'` -eq 1 ]; then
  if [ `echo "$PERL5LIB_new"|grep "/opt/csw/share/perl/csw" | wc -l` -eq 0 ]; then
    PERL5LIB_new="$PERL5LIB_new:/opt/csw/share/perl/csw"
  fi
  if [ `echo "$PERL5LIB_new"|grep "/opt/csw/lib/perl/site_perl" | wc -l` -eq 0 ]; then
    PERL5LIB_new="$PERL5LIB_new:/opt/csw/lib/perl/site_perl"
  fi
fi


perl5lib_slash=`echo "$PERL5LIB_new"|sed -e 's/::/:/g' -e 's/\//\\\\\\//g'`
 
echo "Configuring $HOMELPAR/etc/$wlabel.cfg" 
ed $HOMELPAR/etc/$wlabel.cfg << EOF 2>/dev/null 1>&2
g/__STOR2RRD_HOME__/s/__STOR2RRD_HOME__/$HOMELPAR_slash/g
g/__USER_HOME__/s/__USER_HOME__/$HOME_slash/g
g/__USER__/s/__USER__/$ID/g
g/__STOR2RRD_USER__/s/__STOR2RRD_USER__/$ID/g
g/__RRDTOOL__/s/__RRDTOOL__/$rrd_slash/g
g/__PERL__/s/__PERL__/$per_slash/g
g/__PERL5LIB__/s/__PERL5LIB__/$perl5lib_slash/g
w
q
EOF
ret=$?
if [ ! $ret -eq 0 ]; then
  if [ $ret -eq 127 ]; then
    echo ""
    echo "Error!"
    echo "Probably does not exist command: \"ed\" "
    echo "If it is the case then install ed, \"rm -r $HOMELPAR\" and run install once more"
  else
    echo ""
    echo "Error!"
    echo "Customization of $HOMELPAR/etc/$wlabel.cfg failed"
    echo "Contact product support ... "
  fi
  exit 0
fi

# Solaris ssh does not recognizes -o SendEnv=no
if [ `uname|grep SunOS|wc -l|  sed 's/ //g'` -eq 1 ]; then
ed $HOMELPAR/etc/stor2rrd.cfg << EOF 1>/dev/null
g/ -o SendEnv=no/s/ -o SendEnv=no/ /g
w
q
EOF
fi


cd $HOMELPAR

# change #!bin/ksh in shell script to #!bin/bash on Linux platform
if [ $os_aix -eq 0 ]; then
  # If Linux then change all "#!bin/sh --> #!bin/bash
  for sh in $HOMELPAR/bin/*.sh
  do
  ed $sh << EOF >/dev/null 2>&1
1s/\/ksh/\/bash/
w
q
EOF
  done

  for sh in $HOMELPAR/scripts/*.sh
  do
  ed $sh << EOF >/dev/null 2>&1
1s/\/ksh/\/bash/
w
q
EOF
  done

  for sh in $HOMELPAR/*.sh
  do
  ed $sh << EOF >/dev/null 2>&1
1s/\/ksh/\/bash/
w
q
EOF
  done

  for sh in $HOMELPAR/stor2rrd-cgi/*.sh
  do
  ed $sh << EOF >/dev/null 2>&1
1s/\/ksh/\/bash/
w
q
EOF
  done

else 
  # for AIX Solaris etc, all should be already in place just to be sure ...
  # change all "#!bin/bash --> #!bin/ksh
  for sh in $HOMELPAR/bin/*.sh
  do
  ed $sh << EOF 2>/dev/null 1>&2
1s/\/bash/\/ksh/
w
q
EOF
  done

  for sh in $HOMELPAR/*.sh
  do
  ed $sh << EOF 2>/dev/null 1>&2
1s/\/bash/\/ksh/
w
q
EOF
  done

  for sh in $HOMELPAR/stor2rrd-cgi/*.sh
  do
  ed $sh << EOF 2>/dev/null 1>&2
1s/\/bash/\/ksh/
w
q
EOF
  done

fi

#echo ""
#echo "Custom groups config file creation"
#$HOMELPAR/scripts/update_cfg_custom-groups.sh update

#echo ""
#echo "Favourites config file creation"
#$HOMELPAR/scripts/update_cfg_favourites.sh update

#echo ""
#echo "Alerting config file creation"
#$HOMELPAR/scripts/update_cfg_alert.sh update

# Check web user has read&executable rights for CGI dir stor2rrd-cgi
dir=`echo "$HOMELPAR/www"|sed 's/\\\//g'`
DIR=""
IFS_ORG=$IFS
IFS="/"
for i in $dir
do
  IFS=$IFS_ORG
  NEW_DIR=`echo $DIR$i/`
  #echo "01 $NEW_DIR -- $i -- $DIR ++ $www"
  NUM=`ls -dLl $NEW_DIR |awk '{print $1}'|sed -e 's/d//g' -e 's/-//g' -e 's/w//g' -e 's/\.//g'| wc -c`
  #echo "02 $NUM"
  if [ ! $NUM -eq 7 ]; then
    echo ""
    echo "WARNING, directory : $NEW_DIR has probably wrong rights"| sed 's/\/\//\//g'
    echo "         $www dir and its subdirs have to be executable&readable for WEB user"
    ls -lLd $NEW_DIR| sed 's/\/\//\//g'
    echo ""
  fi
  DIR=`echo "$NEW_DIR/"`
  #echo $DIR
  IFS="/"
done
IFS=$IFS_ORG


if [ $COLLECTOR -eq 0 ]; then

  # ulimit check
  # necessary for big aggregated graphs
  #
  # AIX:
  # chuser  data=8388608  lpar2rrd (4GB)
  # chuser  stack=1048576 lpar2rrd (512MB)
  
  ulimit_message=0
  data=`ulimit -d`
  stack=`ulimit -s`
  if [ $os_aix -eq 1 ]; then
    if [ ! "$data" = "unlimited" -a ! "$data" = "hard" -a ! "$data" = "soft" ]; then
      if [ $data -lt 4194304 ]; then
        echo ""
        echo "Warning: increase data ulimit for $ID user, it is actually too low ($data kB)"
        echo "Assure that the same limits has even the web user (apache/nobody/http)"
        echo "  under root: chuser  data=8388608 $ID # 4GB"
      fi
    fi
    if [ ! "$stack" = "unlimited" -a ! "$stack" = "hard" -a ! "$data" = "soft" ]; then
      if [ $stack -lt 524288  ]; then
        echo ""
        echo "Warning: increase stack ulimit for $ID user, it is actually too low ($stack kB)"
        echo "Assure that the same limits has even the web user (apache/nobody/http)"
        echo "  under root: chuser  stack=1048576 $ID # 512MB"
      fi
    fi
  else # Linux
    if [ ! "$data" = "unlimited" -a ! "$data" = "hard" -a ! "$data" = "soft" ]; then
      if [ $data -lt 4194304 ]; then
        echo ""
        echo "Warning: increase data ulimit for $ID user, it is actually too low ($data kB)"
        echo "Assure that the same limits has even the web user (apache/nobody/http)"
        echo "  under root: vi /etc/security/limits.conf and set 4GB"
        echo "    @$ID        hard    data            4194304"
        echo "    @$ID        soft    data            4194304"
      fi
    fi
    if [ ! "$stack" = "unlimited" -a ! "$stack" = "hard" -a ! "$data" = "soft" ]; then
      if [ $stack -lt 524288  ]; then
        echo ""
        echo "Warning: increase stack ulimit for $ID user, it is actually too low ($stack kB)"
        echo "Assure that the same limits has even the web user (apache/nobody/http)"
        echo "  under root: vi /etc/security/limits.conf and set 512 MB"
        echo "    @$ID        hard    stack           524288"
        echo "    @$ID        soft    stack           524288"
      fi
    fi
  fi

  cd $HOMELPAR
  if [ $os_aix -eq 0 ]; then
    free=`df .|grep -iv filesystem|xargs|awk '{print $4}'`
    freemb=`echo "$free/1048"|bc 2>/dev/null`
    if [ $? -eq 0 -a ! "$freemb"x = "x" ]; then
      if [ $freemb -lt 2048 ]; then
        echo ""
        echo "WARNING: free space in $HOMELPAR is too low : $freemb MB"
        echo "         note that 1 storage needs 1 - 2 GB space depends on number of volumes/pools/ranks/disks/mdisks"
      fi
    fi
  else
    free=`df .|grep -iv filesystem|xargs|awk '{print $3}'`
    freemb=`echo "$free/2048"|bc 2>/dev/null`
    if [ $? -eq 0 -a ! "$freemb"x = "x" ]; then
      if [ $freemb -lt 2048 ]; then
        echo ""
        echo "WARNING: free space in $HOMELPAR is too low : $freemb MB"
        echo "         note that 1 storage needs 1 - 2 GB space depends on number of volumes/pools/ranks/disks/mdisks"
      fi
    fi
  fi
fi

# Check process limits on AIX only
if [ $os_aix -eq 1 ]; then
  maxuproc=`lsattr -El sys0 -a maxuproc| awk '{print $2}'`
  if [ ! "$maxuproc"x = "x" ]; then
    if [ $maxuproc -lt 129 ]; then
      echo ""
      echo "Warning: definitely increase user process limit, it is actually too low ($maxuproc)"
      echo "  under root: chdev -l sys0 -a maxuproc=1024"
    else
      if [ $maxuproc -lt 1024 ]; then
        echo ""
        echo "Warning: increase user process limit, it could be low when you monitoring a lot of devices ($maxuproc)"
        echo "  under root: chdev -l sys0 -a maxuproc=1024"
      fi
    fi
  fi
fi

# setting up the font dir (necessary for 1.3 on AIX)
FN_PATH="<?xml version=\"1.0\"?>
<!DOCTYPE fontconfig SYSTEM \"fonts.dtd\">
<fontconfig>
<dir>/opt/freeware/share/fonts/dejavu</dir>
</fontconfig>"

if [ ! -f "$HOME/.config/fontconfig/.fonts.conf" -o `grep -i deja "$HOME/.config/fontconfig/.fonts.conf" 2>/dev/null|wc -l` -eq 0 ]; then
  if [ ! -d "$HOME/.config" ]; then
    mkdir "$HOME/.config"
  fi
  if [ ! -d "$HOME/.config/fontconfig" ]; then
    mkdir "$HOME/.config/fontconfig"
  fi
  echo $FN_PATH >> "$HOME/.config/fontconfig/.fonts.conf"
fi
chmod 644 "$HOME/.config/fontconfig/.fonts.conf"
# no, no, it issues this error:
# Fontconfig warning: "/opt/freeware/etc/fonts/conf.d/50-user.conf", line 9: reading configurations from ~/.fonts.conf is deprecated.
#if [ ! -f "$HOME/.fonts.conf" ]; then
#  echo $FN_PATH > "$HOME/.fonts.conf"
#  chmod 644 "$HOME/.fonts.conf"
#fi


# for web server user home
if [ ! -d "$HOMELPAR/tmp/home" ]; then
  mkdir "$HOMELPAR/tmp/home"
fi
#if [ ! -f "$HOMELPAR/tmp/home/.fonts.conf" ]; then
#  echo $FN_PATH > "$HOMELPAR/tmp/home/.fonts.conf"
#fi
if [ ! -d "$HOMELPAR/tmp/home/.config" ]; then
  mkdir "$HOMELPAR/tmp/home/.config"
fi
if [ ! -d "$HOMELPAR/tmp/home/.config/fontconfig" ]; then
  mkdir "$HOMELPAR/tmp/home/.config/fontconfig"
fi
if [ ! -f "$HOMELPAR/tmp/home/.config/fontconfig/fonts.conf" ]; then
  echo $FN_PATH >> "$HOMELPAR/tmp/home/.config/fontconfig/fonts.conf"
fi
chmod 755 "$HOMELPAR/tmp/home"
chmod 755 "$HOMELPAR/tmp/home/.config"
chmod 755 "$HOMELPAR/tmp/home/.config/fontconfig"
chmod 644 "$HOMELPAR/tmp/home/.config/fontconfig/fonts.conf"

# RRDTool version checking for graph zooming
$rrd|grep graphv >/dev/null 2>&1
if [ $? -eq 1 -a $COLLECTOR -eq 0 ]; then
  # suggest RRDTool upgrade
  rrd_version=`$rrd -v|head -1|awk '{print $2}'`
  echo "Condider RRDtool upgrade to version 1.3.5+ (actual one is $rrd_version)"
  if [ "$WLABEL" = "STOR2RRD" ]; then
    echo "This will allow graph zooming: http://www.stor2rrd.com/zoom.html"
  fi
  echo ""
fi

os_linux=` uname -s|egrep "^Linux$"|wc -l|sed 's/ //g'`
if [ $os_linux -gt 0 -a $COLLECTOR -eq 0 ]; then
  # LinuxSE warning
  SELINUX=`ps -ef | grep -i selinux| grep -v grep|wc -l`

  if [ "$SELINUX" -gt 0  ]; then
    GETENFORCE=`getenforce 2>/dev/null`
    if [ "$GETENFORCE" = "Enforcing" ]; then
      echo ""
      echo "Warning!!!!!"
      echo "SELINUX status is Enforcing, it might cause a problem during Apache setup"
      echo "like this in Apache error_log: (13)Permission denied: access to /XXXX denied"
      echo ""
    fi
  fi
fi

# comment out LIBPATH on AIX to avoid including /opt/freeware/bin which can cause a problem in some situations
ed $HOMELPAR/etc/$wlabel.cfg << EOF 2>/dev/null 1>&2
g/export LIBPATH=/s/export LIBPATH=/#export LIBPATH=/g
g/  LIBPATH=/s/  LIBPATH=/ #LIBPATH=/g
g/  LIBPATH=/s/  LIBPATH=/ #LIBPATH=/g
g/^STOR2RRD home :/s/^STOR2RRD home : http.*$//g
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/stor2rrd-cgi"/s/stor2rrd-cgi"/$wlabel-cgi"/g
w
q
EOF

if [ $COLLECTOR -eq 0 ]; then
  # create default web dir (it might be changed afterwards but there should be something at least
  if [ ! -f "$HOMELPAR/tmp/menu.txt" -a -f "$HOMELPAR/html/menu_default.txt" ]; then
    #place default menu.txt
    cp $HOMELPAR/html/menu_default.txt $HOMELPAR/tmp/menu.txt
  fi
  cp -R $HOMELPAR/html/* $HOMELPAR/www/ 2>/dev/null
fi

# Apache authorization, it must be here because path has to be modified as per installation home
if [ "$WLABEL" = "CIRO" ]; then
  cat << END > $HOMELPAR/html/.htaccess
SetEnv XORUX_ACCESS_CONTROL 1
AuthUserFile $HOMELPAR/etc/web_config/htusers.cfg
AuthName "Authorized personnel only."
AuthType Basic
Require valid-user
<Files "index.html">
  Header append Set-Cookie "cgi-path=/ciro-cgi"
</Files>
END
  
  if [ -f $HOMELPAR/www/.htaccess ]; then
    if [ `grep "ciro-cgi" $HOMELPAR/www/.htaccess 2>/dev/null| wc -l| sed 's/ //g'` -eq 0 ]; then
      cp $HOMELPAR/html/.htaccess $HOMELPAR/www/.htaccess
    fi
  fi
else
  cat << END > $HOMELPAR/html/.htaccess
SetEnv XORUX_ACCESS_CONTROL 1
AuthUserFile $HOMELPAR/etc/web_config/htusers.cfg
AuthName "Authorized personnel only."
AuthType Basic
Require valid-user
END
fi


if [ $os_aix -eq 1 ]; then
  # AIX (at least) rrdtool 1.7 issue when prints mem profiling info to pwd/mon.out
  touch $HOMELPAR/$wlabel-cgi/mon.out
  chmod 777 $HOMELPAR/$wlabel-cgi/mon.out
  touch $HOMELPAR/bin/mon.out
  chmod 777 $HOMELPAR/bin/mon.out

  # refresh font caching
  # it creates it in /home/stor2rrd/tmp/home/.cache/fontconfig and in /home/stor2rrd/.cache/fontconfig
  if [ ! -d "$HOMELPAR/tmp/home" ]; then
    mkdir "$HOMELPAR/tmp/home"
  fi
  fc-cache -fv 1>/dev/null 2>&1
  HOME="$HOMELPAR/tmp/home"; fc-cache -fv 1>/dev/null 2>&1
fi

# IPv6 support, however not on AIX, there is an issue
if [ ! $os_aix -eq 1 ]; then
  rhel_ver_check=`rpm --eval '%{rhel}'`
  if [ $? -eq 0 ]; then
    # skip CentOS 6 and older
    if [ ! -n "$rhel_ver_check" ] || [ `echo $rhel_ver_check| grep rhel| wc -l| sed 's/ //g'` -eq 1 ] || [ "$rhel_ver_check" -gt 6 ]; then
      for file_snmp in $HOMELPAR/bin/*.pl
      do
ed $file_snmp << EOF 1>/dev/null 2>/dev/null
g/IO::Socket::INET/s/IO::Socket::INET/IO::Socket::IP/g
w
q
EOF
      done
      for file_snmp in $HOMELPAR/bin/*.pm
      do
ed $file_snmp << EOF 1>/dev/null 2>/dev/null
g/IO::Socket::INET/s/IO::Socket::INET/IO::Socket::IP/g
w
q
EOF
      done
    fi
  else
    # OS version not found, go ahead only in case of Linux
    if [ `uname -s` = "Linux" ]; then
      for file_snmp in $HOMELPAR/bin/*.pl
      do
ed $file_snmp << EOF 1>/dev/null 2>/dev/null
g/IO::Socket::INET/s/IO::Socket::INET/IO::Socket::IP/g
w
q
EOF
      done
      for file_snmp in $HOMELPAR/bin/*.pm
      do
ed $file_snmp << EOF 1>/dev/null 2>/dev/null
g/IO::Socket::INET/s/IO::Socket::INET/IO::Socket::IP/g
w
q
EOF
      done
    fi
  fi
fi

rm -f $HOMELPAR/bin/tatlin* $HOMELPAR/load_tatlinperf.sh $HOMELPAR/bin/raidix* $HOMELPAR/bin/RAIDIX.pm $HOMELPAR/bin/TATLIN.pm


# Checking installed Perl modules, it must be after above IPv6
cd $HOMELPAR
. $HOMELPAR/etc/$wlabel.cfg; export INPUTDIR=$HOMELPAR; $PERL bin/perl_modules_check.pl $PERL
echo ""


echo ""
echo "Installation has finished"
echo "Follow detailed installation instructions at :"
if [ "$WLABEL" = "STOR2RRD" ]; then
  echo "  http://www.stor2rrd.com/install.htm"
fi

date=`date "+%Y-%m-%d_%H:%M"`
echo "$version $date" >> $HOMELPAR/etc/version.txt
echo "$HOMELPAR" > $HOME_ORG/.${wlabel}_home 2>/dev/null

