#!/bin/sh
#
# STOR2RRD update script
# usage : ./update.sh
#         ./update.sh nocheck  # consistency check of RRDTool files is excluded
#
#

LANG=C
export LANG

check=1
if [ ! "$1"x = "x" ]; then
  if [ "$1" = "nocheck" ]; then
    check=0
  fi
fi

AWK="awk"
if [ `uname -s` = "SunOS" ]; then
  AWK="nawk"
fi

os_aix=` uname -s|egrep "^AIX$"|wc -l|sed 's/ //g'`


DEBUG_UPD=0
ID=`id -un`

umask 022

# test if "ed" command does not exist, it might happen especially on some Linux distros
ed << END 2>/dev/null 1>&2
q
END
if [ $? -gt 0 ]; then
  echo "ERROR: "ed" command does not seem to be installed or in $PATH"
  echo "Exiting ..."
  exit 1
fi

wlabel=stor2rrd
WLABEL=STOR2RRD

wlabel_company="xorux"
WLABEL_COMPANY="XORUX"
wlabel_domain="com"
wlabel_docu=""


if [ -f wlabel.txt ]; then
  wlabel=`cat wlabel.txt| tail -1`
  WLABEL=`echo $wlabel| tr '[:lower:]' '[:upper:]'`
fi

if [ "$WLABEL" = "BREAKPOINT" ]; then
  # just do a record in etc/.magic, nothing else, return wlabel to original
  wlabel=stor2rrd
  WLABEL=STOR2RRD
fi

if [ "$WLABEL" = "CIRO" ]; then
  wlabel_company="cutaway"
  WLABEL_COMPANY="Cutaway"
  wlabel_domain="it"
  wlabel_docu="documentation-ciro"
fi

if [ -d $HOME/$wlabel ]; then
  HOME1=$HOME/$wlabel
else
  if [ -d $HOME/stor2rrd ]; then
    HOME1=$HOME/stor2rrd
  fi
fi

if [ -f "$HOME/etc/.magic" ]; then
  .  $HOME/etc/.magic
fi

if [ "$WLABEL" = "Dark" ]; then
  # clean it when Dark theme is set from hist reasons, this is not real white labeling
  WLABEL=STOR2RRD
fi

if [ -f "/home/$wlabel/$wlabel/etc/.magic" ]; then
  .  /home/$wlabel/$wlabel/etc/.magic
fi

if [ `ps -ef|egrep "/load.sh"|egrep -v "grep"|grep $wlabel|wc -l` -gt 0 ]; then
  kill `ps -ef|egrep "load.sh"|egrep -v "grep"|grep $wlabel|$AWK '{print $2}'|xargs` 2>/dev/null
  sleep 2
fi

if [ $os_aix -eq 0 ]; then
  ECHO_OPT="-e"
else
  ECHO_OPT=""
fi


echo "Product upgrade under user : \"$ID\""
echo ""
if [ -f "$HOME/.${wlabel}_home" ]; then
  HOME1=`cat "$HOME/.${wlabel}_home"`
else
  if [ -f "$HOME/.stor2rrd_home" ]; then
    HOME1=`cat "$HOME/.stor2rrd_home"`
  fi
fi

if [ ! "$HOME1"x = "x" -a -d "$HOME1" ]; then
  echo $ECHO_OPT "Where is the product actually located [$HOME1]: \c"
else
  if [ x"$HOME1" = "x" ]; then
    echo $ECHO_OPT "Where is the product actually located: \c"
  else
    echo $ECHO_OPT "Where is the product actually located [$HOME1]: \c"
  fi
fi

# check if it is running from the image, then no wait for the input
if [ "$VM_IMAGE"x = "x" ]; then
  read HOMELPAR
else
  if [ $VM_IMAGE -eq 0 ]; then
    read HOMELPAR
  else
    echo ""
    echo "$HOME1"
  fi
fi

if [ x"$HOMELPAR" = "x" ]; then
  HOMELPAR=$HOME1
fi

if [ -f "$HOMELPAR/etc/.magic" ]; then
  .  $HOMELPAR/etc/.magic
fi

# Check if it runs under the right user
check_file="$HOMELPAR/bin/storage.pl"
if [ ! -f "$check_file" ]; then
  check_file="$HOMELPAR/storage.pl"
  if [ ! -f "$check_file" ]; then
    echo "The product has not been found in: $HOMELPAR"
    exit 1
  fi
fi

if [ `uname -s` = "SunOS" ]; then
  # Solaris does not have -X
  install_user=`ls -l "$check_file"|$AWK '{print $3}'`
else
  install_user=`ls -lX "$check_file"|$AWK '{print $3}'` # must be X to do not cut user name to 8 chars
fi

running_user=`id |$AWK -F\( '{print $2}'|$AWK -F\) '{print $1}'`
if [ ! "$install_user" = "$running_user" ]; then
  echo "You probably trying to run it under wrong user"
  echo "The product files are owned by : $install_user"
  echo "You are : $running_user"
  echo "The product update should run only under user which owns installed package"
  echo "Do you want to really continue? [n]:"
  # check if it is running from the image, then no wait for the input
  read answer
  if [ "$answer"x = "x" -o "$answer" = "n" -o "$answer" = "N" ]; then
    exit 1
  fi
fi


export INPUTDIR=$HOMELPAR
if [ ! "$WLABEL" = "STOR2RRD" ]; then
  CFG=$HOMELPAR/etc/$wlabel.cfg
  if [ ! -f $CFG -a -f $HOMELPAR/etc/stor2rrd.cfg ]; then
    # initial upgrade to white label
    mv $HOMELPAR/etc/stor2rrd.cfg $CFG
  fi
else
  CFG=$HOMELPAR/etc/stor2rrd.cfg
fi

cp -p $CFG $CFG-backup

if [ ! -f "$CFG" ]; then
 echo "Could not find config file $CFG, the product is not installed there, exiting"
 exit 1
fi

if [ -f $HOMELPAR/etc/version.txt ]; then
  version=`egrep "[0-9]\.[0-9]" $HOMELPAR/etc/version.txt|tail -1|sed 's/ .*//'`
  VER=`egrep "[0-9]\.[0-9]" $HOMELPAR/etc/version.txt|tail -1|sed 's/ .*//'|sed 's/-.*$//'`  # get only major version info
else
  # old version of getting version
  if [ `grep "# version " $CFG|wc -l` -eq 1 ]; then
    VER=`egrep "# version " $CFG|tail -1|$AWK '{print $3}'`
  else
    VER=`egrep "version=" $CFG|tail -1|$AWK -F= '{print $2}'`
  fi
  version=$VER
fi

if [ "$VER" = "" ]; then
  # very old version did not have version string inside, so putting here something low
  VER="1"
fi
VER_ORG=`echo $VER|sed 's/\.//g'`
version_org=$version

# remove cmd files of pool back-end data from beta testing
if [ $VER_ORG -lt 272 ]; then
  # remove VMAX command files, in case of storage resource pools is not used
  rm -f $HOMELPAR/tmp/*/POOL-alloc*cmd
fi

# Remove XorMon DB
if [ $VER_ORG -lt 709 ]; then
  if [ -f "$HOMELPAR/data/_DB/data.db" ]; then
    if [ "$DEMO"x = "x" ]; then
      echo ""
      echo "Removing XorMon configuration database, it will be re-created automatically within an hour"
      echo ""
      rm -f $HOMELPAR/data/_DB/*
    fi
  fi
fi

if [ $VER_ORG -lt 702 ]; then
  if [ -f "$HOMELPAR/data/_DB/data.db" ]; then
    echo ""
    echo "Removing Xormon DB, wait 1 hour after the upgrade to get your Xormon storage menu back"
    echo ""
    rm -f "$HOMELPAR/data/_DB/data.db"
  fi
fi


# remove capacity data, beta stuff
if [ $VER_ORG -lt 690 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ -f "$storage_all/SWIZ-FLASH" -o -f "$storage_all/SWIZ" ]; then
      storage=`basename $storage_all`
      if [ -d "$HOMELPAR/data/$storage/CAPACITY/" ]; then
        rm -rf $HOMELPAR/data/$storage/CAPACITY/*
      fi
    fi
  done
fi

if [ $VER_ORG -lt 283 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ -f "$storage_all/CEPH" ]; then
      storage=`basename $storage_all`
      echo "CEPH: removing demo data: rm -rf $HOMELPAR/data/$storage/BACKEND*"
      rm -rf $HOMELPAR/data/$storage/BACKEND*
    fi
  done
fi

# remove cmd files of response time for DATACORE Volumes (not used any more)
if [ $VER_ORG -lt 236 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ -f "$storage_all/SWIZ-FLASH" ]; then
      storage=`basename $storage_all`
      rm -f $HOMELPAR/tmp/$storage/POOL-*_b-*
    fi
  done
fi

# remove cmd files of response time for DATACORE Volumes (not used any more)
if [ $VER_ORG -lt 235 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ -f "$storage_all/DATACORE" ]; then
      storage=`basename $storage_all`
      rm -f $HOMELPAR/tmp/$storage/VOLUME-resp_t*
    fi
  done
fi

# remove cmd files of TIER for STOREVIRT (not used any more)
if [ $VER_ORG -lt 235 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ -f "$storage_all/STOREVIRTUAL" ]; then
      storage=`basename $storage_all`
      rm -f $HOMELPAR/tmp/$storage/TIER*
    fi
  done
fi

if [ $VER_ORG -lt 235 ]; then
  # remove MIB which should not be there after 2.34-2
  rm -f $HOMELPAR/MIBs/CISCO-VTP-MIB.mib
fi

# modify custom groups cfg to be compatible with new regex usage
if [ $VER_ORG -lt 234 ]; then
  if [ -f "$HOMELPAR/etc/web_config/custom_groups.cfg" ]; then
    if [ `egrep -v "^#" $HOMELPAR/etc/web_config/custom_groups.cfg | wc -l| sed 's/ //g'` -gt 0 ]; then
      if [ ! -f $HOMELPAR/etc/.web_config/custom_groups.cfg-upgrade-$VER ]; then
        cp $HOMELPAR/etc/web_config/custom_groups.cfg $HOMELPAR/etc/.web_config/custom_groups.cfg-upgrade-$VER
      fi
      echo "Adjusting custom group setup"
      sed -e 's/\\/\\\\/g' -e 's/\[/\\[/g' -e 's/\]/\\]/g' -e 's/\^/\\^/g' -e 's/\$/\\$/g' -e 's/\./\\./g' -e 's/\*/\\*/g' -e 's/\+/\\+/g' -e 's/\?/\\?/g' -e 's/|/\\|/g' -e 's/(/\\(/g' -e 's/)/\\)/g' -e 's/{/\\{/g' -e 's/}/\\}/g' $HOMELPAR/etc/.web_config/custom_groups.cfg-upgrade-$VER > $HOMELPAR/etc/web_config/custom_groups.cfg
    fi
  fi
fi

# remove SAN switch cfg to force refresh
if [ $VER_ORG -lt 212 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ ! "$DEMO"x = "x" ]; then
       if [ $DEMO -eq 1 ]; then
         break # skip on demo
       fi
    fi
    if [ -f "$storage_all/SAN-CISCO" -o -f "$storage_all/SAN-BRCD" ]; then
      storage=`basename $storage_all`
      rm -f $WEBDIR/$storage/config.html
    fi
  done
fi

# remove wrong PORT rrd file for DATADOMAIN (during beta testing)
if [ $VER_ORG -lt 213 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ ! "$DEMO"x = "x" ]; then
       if [ $DEMO -eq 1 ]; then
         break # skip on demo
       fi
    fi
    if [ -f "$storage_all/DATADOMAIN" ]; then
      storage=`basename $storage_all`
      rm -f $HOMELPAR/data/$storage/PORT/*rrd
    fi
  done
fi

# remove wrong POOL and VOLUME-FOLDER for Nimble (beta testing)
if [ $VER_ORG -lt 215 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ ! "$DEMO"x = "x" ]; then
       if [ $DEMO -eq 1 ]; then
         break # skip on demo
       fi
    fi
    if [ -f "$storage_all/NIMBLE" ]; then
      storage=`basename $storage_all`
      rm -f $HOMELPAR/data/$storage/POOL/*rrd
      rm -f $HOMELPAR/data/$storage/POOL/*first
      rm -f $HOMELPAR/data/$storage/VOLUME-FOLDER/*rrd
    fi
  done
fi

# remove DISK data for DataCore (beta testing)
if [ $VER_ORG -lt 221 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ ! "$DEMO"x = "x" ]; then
       if [ $DEMO -eq 1 ]; then
         break # skip on demo
       fi
    fi
    if [ -f "$storage_all/DATACORE" ]; then
      storage=`basename $storage_all`
      rm -f $HOMELPAR/data/$storage/DRIVE/*rrd
    fi
  done
fi

## remove touch file (storage VSPG) in IOSTATS (new configuration after upgrade)
for storage_all in $HOMELPAR/data/*
do
  if [ -f "$storage_all/VSPG" ]; then
    storage=`basename $storage_all`
    rm -f $HOMELPAR/data/$storage/IOSTATS/configuration/config-$storage\.touch 2>/dev/null
  fi
done

##



# 3PAR changes
if [ $VER_ORG -lt 194 ]; then
  par_once=0
  for storage_all in $HOMELPAR/data/*
  do
    if [ ! "$DEMO"x = "x" ]; then
       if [ $DEMO -eq 1 ]; then
         break # skip on demo
       fi
    fi
    if [ -f "$storage_all/3PAR" ]; then
      storage=`basename $storage_all`
      if [ -d "$storage_all/RANK" ]; then
        if [ $par_once -eq 0 ]; then
          par_once=1
          echo ""
          echo "3PAR storage has been identified "
          echo "Note that POOL back-end data for all 3PAR storages will be deleted due to new implementation"
          echo "Type enter to continue or Ctrl-C to interrupt installation"
          read answer
        fi
        echo "Removing 3PAR Raid Group DB files not longer used for $storage_name: rm -f $storage_all/RANK/*"
        rm -rf $storage_all/RANK
        rm -f $HOMELPAR/tmp/$storage/RANK*
      fi
      if [ -f $storage_all/NODE/0.rrd ]; then
        rm -rf $storage_all/NODE/* # 1.91.X beta contained wrong names
        rm -f $HOMELPAR/tmp/*/*cfc_max*.cmd # 1.91.X beta contained cfc_max, not using it anymore
      fi
      # removing command files, no need to print it out
      rm -f $HOMELPAR/tmp/$storage/POOL*  # remove POOL front end cmd files due to change 3PAR backend in 1.35-2

      rm -f $storage_all/VOLUME/*rrs
      if [ ! -d "$storage_all/VVOL" -a  -d "$storage_all/VOLUME" ]; then
        echo "Renaming VOLUME data to vVOL for $storage_name"
        mv "$storage_all/VOLUME" "$storage_all/VVOL"
      fi
      # removing old named file of node tiers (it has existed just a short time during beta testing)
      rm -f $storage_all/NODE/*-[0,1].rrt
      # vLUN cmd files used only for respose times, also for short time during beta testing
      rm -f $HOMELPAR/tmp/$storage/LUN-resp_t*
    fi
  done
fi

# remove wrong PORT cmd files (they are not used)
if [ $VER_ORG -lt 210 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ ! "$DEMO"x = "x" ]; then
       if [ $DEMO -eq 1 ]; then
         break # skip on demo
       fi
    fi
    if [ -f "$storage_all/DS8K" ]; then
      storage=`basename $storage_all`
      rm -f $HOMELPAR/tmp/$storage/PORT-sum_io-d.cmd $HOMELPAR/tmp/$storage/PORT-sum_io-m.cmd $HOMELPAR/tmp/$storage/PORT-sum_io-w.cmd $HOMELPAR/tmp/$storage/PORT-sum_io-y.cmd $HOMELPAR/tmp/$storage/PORT-sum_io_trend-y.cmd
    fi
  done
fi

# remove old beta rrdfiles created with other number of items
if [ $VER_ORG -lt 205 ]; then
  for storage_all in $HOMELPAR/data/*
  do
    if [ ! "$DEMO"x = "x" ]; then
       if [ $DEMO -eq 1 ]; then
         break # skip on demo
       fi
    fi
    if [ -f "$storage_all/COMPELLENT" ]; then
      storage=`basename $storage_all`
      rm -f $HOMELPAR/data/$storage/POOL/*rrd $HOMELPAR/data/$storage/POOL/*first
    fi
  done
fi


# removing cache data as DelAck was wrong (it was counter saved as gauge)
if [ $VER_ORG -lt 200 -o $VER_ORG -eq 200 ]; then
  # kill all 3par processes to do not allow create new perf file
  kill `ps -ef| grep 3par| grep -v grep| $AWK '{print $2}'| xargs` 2>/dev/null
  sleep 1
  for storage_all in $HOMELPAR/data/*
  do
    if [ ! "$DEMO"x = "x" ]; then
       if [ $DEMO -eq 1 ]; then
         break # skip on demo
       fi
    fi
    if [ -f "$storage_all/3PAR" ]; then
      storage=`basename $storage_all`
      echo "3PAR DelAck fix for $storage"
      # remove all cache rrd files
      rm -f $storage_all/NODE/*rrt
      # remove all unprocessed perf files as DelAck might be wrong there
      rm -f $storage_all/*.out
    fi
  done
fi

pwd=`pwd`
touch test
if [ ! $? -eq 0 ]; then
  echo "Actual user does not have rights to create files in actual directory: $pwd "
  echo "Fix it and re-run upgrade"
  exit 1
fi
rm -f test

if [ -f $wlabel.tar.Z ]; then
  which uncompress >/dev/null 2>&1
  if [ $? -eq 0 ]; then
     uncompress -f $wlabel.tar.Z
     if [ ! $? -eq 0 ]; then
       echo "Package uncomress encountered a problem"
       echo "Check if actual user owns directory and if there is enough of disk space"
       echo "Exiting without any change"
       exit 1
     fi
  else
     which gunzip >/dev/null 2>&1
     if [ $? -eq 0 ]; then
       gunzip -f $wlabel.tar.Z
       if [ ! $? -eq 0 ]; then
         echo "Package uncomress encountered a problem"
         echo "Check if actual user owns directory and if there is enough of disk space"
         echo "Exiting without any change"
         exit 1
       fi
     else
       echo "Could not locate uncompress or gunzip commands. exiting"
       exit  1
     fi
  fi
fi

if [ -f $wlabel.tar ]; then
  tar xf $wlabel.tar
  if [ ! $? -eq 0 ]; then
    echo "Package extraction encountered a problem"
    echo "Check if actual user owns directory and if there is enough of disk space"
    echo "Exiting without any change"
    exit 1
  fi
else
  echo "looks like it is already extracted, tar is missing"
fi

if [ ! -d "dist_storage" ]; then
  echo "There is not \"dist_storage\", data was not extracted properly"
  echo "Check if actual user owns directory and if there is enough of disk space"
  echo "Exiting without any change"
  exit 1
fi

cd dist_storage

# Read original configuration
WEBDIR=`sed 's/#.*$//g' $CFG|egrep "WEBDIR=" | tail -1|$AWK -F = '{print $2}'    |sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
WEB_CGI_PATH=`sed 's/#.*$//g' $CFG|egrep "WEB_CGI_PATH=" | tail -1|$AWK -F = '{print $2}'    |sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
DS8_USER=`sed 's/#.*$//g' $CFG|egrep "DS8_USER=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
STORAGE_USER=`sed 's/#.*$//g' $CFG|egrep "STORAGE_USER=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
DS8_CLIDIR=`sed 's/#.*$//g' $CFG|egrep "DS8_CLIDIR=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
DS5_CLIDIR=`sed 's/#.*$//g' $CFG|egrep "DS5_CLIDIR=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
HUS_CLIDIR=`sed 's/#.*$//g' $CFG|egrep "HUS_CLIDIR=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
VSP_CLIDIR=`sed 's/#.*$//g' $CFG|egrep "VSP_CLIDIR=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
HPE3PAR_CLIDIR=`sed 's/#.*$//g' $CFG|egrep "HPE3PAR_CLIDIR=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
VNX_BLOCK_CLIDIR=`sed 's/#.*$//g' $CFG|egrep "VNX_BLOCK_CLIDIR=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
UNITY_CLIDIR=`sed 's/#.*$//g' $CFG|egrep "UNITY_CLIDIR=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
VNXE_CLIDIR=`sed 's/#.*$//g' $CFG|egrep "VNXE_CLIDIR=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
HDS_EXPORT_TOOL_JAVAPATH=`sed 's/#.*$//g' $CFG|egrep "HDS_EXPORT_TOOL_JAVAPATH=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
STORAGE_CFG=`sed 's/#.*$//g' $CFG|egrep "STORAGE_CFG=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
SAN_CFG=`sed 's/#.*$//g' $CFG|egrep "SAN_CFG=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
LAN_CFG=`sed 's/#.*$//g' $CFG|egrep "LAN_CFG=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
eval ERRLOG=` sed 's/#.*$//g' $CFG|egrep "ERRLOG=" | tail -1|$AWK -F = '{print $2}'| sed -e 's/ //g'|sed 's/ /\\\\ /g'`
ERRLOG=`echo $ERRLOG  |sed 's/\//\\\\\\\\\//g'` # It us due to $INPUTDIR which is used in old version and its evaulation, no other way
PERL=`sed 's/#.*$//g' $CFG|egrep "PERL=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
# PERL_act save actual perl with no backslashes in path
PERL_act=`sed 's/#.*$//g' $CFG|egrep "PERL=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/ //g'|sed 's/ /\\\\ /g'`
RRD=`sed 's/#.*$//g' $CFG|egrep "RRDTOOL=" | tail -1|$AWK -F = '{print $2}' |sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'|sed 's/ /\\\\ /g'`
RRD_act=`sed 's/#.*$//g' $CFG|egrep "RRDTOOL=" | tail -1|$AWK -F = '{print $2}' |sed -e 's/ //g'|sed -e 's/        //g' -e 's/ /\\\\ /g'`
SAMPLE_RATE=`sed 's/#.*$//g' $CFG|egrep "SAMPLE_RATE=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
VOLUME_IO_MAX=`sed 's/#.*$//g' $CFG|egrep "VOLUME_IO_MAX=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
VOLUME_DATA_MAX=`sed 's/#.*$//g' $CFG|egrep "VOLUME_DATA_MAX=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
VOLUME_RESPONSE_MAX=`sed 's/#.*$//g' $CFG|egrep "VOLUME_RESPONSE_MAX=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
VOLUME_CACHE_MAX=`sed 's/#.*$//g' $CFG|egrep "VOLUME_CACHE_MAX=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
RRDHEIGHT=`sed 's/#.*$//g' $CFG|egrep "RRDHEIGHT=" $CFG|egrep -v "#|DASHB_"| tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
RRDWIDTH=`sed 's/#.*$//g' $CFG|egrep "RRDWIDTH=" $CFG|egrep -v "#|DASHB_"| tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
DASHB_RRDHEIGHT=`sed 's/#.*$//g' $CFG|egrep "DASHB_RRDHEIGHT=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
DASHB_RRDWIDTH=`sed 's/#.*$//g' $CFG|egrep "DASHB_RRDWIDTH=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
PERL5LIB=`sed 's/#.*$//g' $CFG|egrep "PERL5LIB=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/ //g'|sed 's/ /\\\\ /g'` # --> it is further modifified below !!!
DEBUG=`sed 's/#.*$//g' $CFG|egrep "DEBUG=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
PICTURE_COLOR=`sed 's/#.*$//g' $CFG|egrep "PICTURE_COLOR=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
TOPTEN=`sed 's/#.*$//g' $CFG|egrep "TOPTEN=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
LEGEND_HEIGHT=`sed 's/#.*$//g' $CFG|egrep "LEGEND_HEIGHT=" | tail -1|$AWK -F = '{print $2}'|sed 's/ /\\\\ /g'`
PDF_PAGE_SIZE=`sed 's/#.*$//g' $CFG|egrep "PDF_PAGE_SIZE=" | tail -1|$AWK -F = '{print $2}'|sed -e 's/	//g' -e 's/ //g'`
SSH=`sed 's/#.*$//g' $CFG|egrep "SSH=" | tail -1| sed -e 's/^.*SSH=//' -e 's/"//g' -e 's/       //g' -e 's/\//\\\\\\\\\//g'`

if [ -f ../version.txt ]; then
  # actually installed version
  version_new=`cat ../version.txt|tail -1|sed 's/ .*//'`
fi

if [ "$SSH"x = "x" ]; then
  # upgrade from 1.x version where SSH has not been in cfg
  SSH="ssh -q"
fi
# if OpenSSH then place there: -o ConnectTimeout=80 -o StrictHostKeyChecking=no -o PreferredAuthentications=publickey
if [ `$SSH -V 2>&1|grep -i OpenSSH|wc -l` -eq 1 ]; then
  if [ `echo "$SSH"|grep -i ConnectTimeout|wc -l` -eq 0 ]; then
    SSH_tmp="$SSH"
    SSH=`echo "$SSH_tmp -o ConnectTimeout=80 -o StrictHostKeyChecking=no -o PreferredAuthentications=publickey "`
  fi
  if [ `echo "$SSH"|grep -i SendEnv|wc -l` -eq 0 ]; then
    SSH_tmp="$SSH"
    SSH=`echo "$SSH_tmp -o SendEnv=no "`
  fi
fi
if [ `echo "$SSH"|grep -- "-q" |wc -l` -eq 0 ]; then
  # "-q" must be there always
  SSH_tmp="$SSH"
  SSH="$SSH_tmp -q "
fi
SSH_tmp=$SSH

# Solaris ssh does not recognize -o SendEnv=no
if [ `uname|grep SunOS|wc -l|  sed 's/ //g'` -eq 1 ]; then
  SSH=`echo $SSH_tmp|sed -e 's/\//\\\\\\\\\//g' -e 's/ /\\\\ /g' -e 's/^/\\\\"/'  -e 's/$/\\\\ \\\\"/'|sed 's/ -o SendEnv=no/ /g'`
else
  SSH=`echo $SSH_tmp|sed -e 's/\//\\\\\\\\\//g' -e 's/ /\\\\ /g' -e 's/^/\\\\"/'  -e 's/$/\\\\ \\\\"/'`
fi


# find out if LIBPATH is set
aix_libpath=`sed 's/#.*$//g' $CFG|egrep "LIBPATH=" |grep freeware| wc -l`


WEBDIR_PLAIN=`echo $WEBDIR | sed 's/\\\//g'`


if [ "$STORAGE_USER"X = "X" ]; then
  STORAGE_USER=$DS8_USER
fi
if [ "$DS8_CLIDIR"X = "X" ]; then
  DS8_CLIDIR=`echo "/opt/ibm/dscli"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$DS5_CLIDIR"X = "X" ]; then
  DS5_CLIDIR=`echo "/usr/SMclient"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$HUS_CLIDIR"X = "X" ]; then
  HUS_CLIDIR=`echo "/usr/stonavm"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$VSP_CLIDIR"X = "X" ]; then
  VSP_CLIDIR=`echo "/usr"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$HPE3PAR_CLIDIR"X = "X" ]; then
  HPE3PAR_CLIDIR=`echo "/opt/hp_3par_cli/bin"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$VNX_BLOCK_CLIDIR"X = "X" ]; then
  if [ $os_aix -eq 1 ]; then
    VNX_BLOCK_CLIDIR=`echo "/usr/bin"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
  else
    VNX_BLOCK_CLIDIR=`echo "/opt/Navisphere/bin"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
  fi
fi

if [ "$UNITY_CLIDIR"X = "X" ]; then
  UNITY_CLIDIR=`echo "/usr/bin"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$VNXE_CLIDIR"X = "X" ]; then
  VNXE_CLIDIR=`echo "/usr/bin"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$HDS_EXPORT_TOOL_JAVAPATH"X = "X" ]; then
  HDS_EXPORT_TOOL_JAVAPATH=`echo "/usr/java8_64/jre/bin:/usr/java8_32/jre/bin:/usr/bin"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$WEB_CGI_PATH"X = "X" ]; then
  WEB_CGI_PATH=`echo "/stor2rrd-cgi"|sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$VOLUME_DATA_MAX"X = "X" ]; then
  VOLUME_DATA_MAX=1024
fi

if [ "$VOLUME_IO_MAX"X = "X" ]; then
  VOLUME_IO_MAX=50
fi

if [ "$VOLUME_RESPONSE_MAX"X = "X" ]; then
  VOLUME_RESPONSE_MAX=0.1
fi

if [ $VOLUME_RESPONSE_MAX = "2" ]; then
  # lower that limit since v2.60 to follow nowadays disk speeds
  VOLUME_RESPONSE_MAX=0.1
fi

if [ "$VOLUME_CACHE_MAX"X = "X" ]; then
  VOLUME_CACHE_MAX=1024
fi

if [ "$TOPTEN"X = "X" ]; then
  TOPTEN=11
fi

if [ "$SAN_CFG"X = "X" ]; then
  SAN_CFG=`echo "$HOMELPAR/etc/san-list.cfg" |sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$LAN_CFG"X = "X" ]; then
  LAN_CFG=`echo "$HOMELPAR/etc/lan-list.cfg" |sed -e 's/\//\\\\\\\\\//g' -e 's/ //g'`
fi

if [ "$RRDHEIGHT"X = "X" -o $RRDHEIGHT -eq 50 ]; then
  RRDHEIGHT=150
fi

if [ "$RRDWIDTH"X = "X" -o $RRDWIDTH -eq 120 ]; then
  RRDWIDTH=700
fi

if [ "$DASHB_RRDHEIGHT"X = "X" ]; then
  DASHB_RRDHEIGHT=50
fi

if [ "$DASHB_RRDWIDTH"X = "X" ]; then
  DASHB_RRDWIDTH=120
fi

if [ "$PDF_PAGE_SIZE"X = "X" ]; then
  PDF_PAGE_SIZE=A4
fi

if [ "$LEGEND_HEIGHT"X = "X" ]; then
  LEGEND_HEIGHT=120
fi

if [ "$SSH"X = "X" ]; then
  SSH=`echo "ssh" |sed -e 's/\//\\\\\\\\\//g' -e 's/ /\\\\ /g' -e 's/^/\\\\"/'  -e 's/$/\\\\ \\\\"/'`
fi

if [ "$PICTURE_COLOR"X = "X" -o "$PICTURE_COLOR" = "D3D2D2" -o "$PICTURE_COLOR" = "E3E2E2" -o "$PICTURE_COLOR" = "F7FCF8" ]; then
  PICTURE_COLOR=F7F7F7
fi

if [ "$DEBUG"X = "X" ]; then
  DEBUG=1
fi

echo "$PERL5LIB"|grep ":" >/dev/null 2>&1
if [ ! $? -eq 0 ]; then
    PERL5LIB=/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi:/usr/lib64/perl5:/opt/freeware/lib/perl/5.8.8:/opt/freeware/lib/perl/5.8.0:/usr/opt/perl5/lib/site_perl/5.8.2:/usr/lib/perl5/vendor_perl/5.8.5:/usr/share/perl5:/usr/lib/perl5:/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi:/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi
fi

bit64=`file $PERL_act 2>/dev/null| grep 64-bit| wc -l | sed 's/ //g'`

# add actual paths
# This /usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi must be befor /usr/opt/perl5/lib/site_perl/5.10.1/aix-thread-multi when is /opt/freeware/bin/perl used otherwisi is usede wrong SSLeay.so
# (https.pm is not found then)
if [ "$PERL_act" = "/opt/freeware/bin/perl" ]; then
  # AIX, excluded /usr/opt/perl5/lib64/5.28.1 which causing a problem
  PPATH="/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi
/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0/ppc-aix-thread-multi
/usr/lib64/perl5
/opt/freeware/lib/perl5/vendor_perl/5.8.8
/opt/freeware/lib/perl5
/opt/freeware/lib/perl
/usr/opt/perl5/lib/site_perl
/usr/lib/perl5/vendor_perl
/usr/lib64/perl5/vendor_perl
/opt/csw/share/perl/csw
/usr/opt/perl5/lib/site_perl/5.10.1/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.28.0/ppc-aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.8.8/ppc-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0
/usr/opt/perl5/lib/site_perl/5.10.1
/usr/opt/perl5/lib/site_perl/5.28.1
/usr/share/perl5/vendor_perl"
else
  if [ $bit64 -eq 0 ]; then
    PPATH="/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi
/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0/ppc-aix-thread-multi
/opt/freeware/lib/perl5/vendor_perl/5.8.8
/opt/freeware/lib/perl5
/opt/freeware/lib/perl
/usr/opt/perl5/lib/site_perl
/usr/lib/perl5/vendor_perl
/opt/csw/share/perl/csw
/usr/opt/perl5/lib/site_perl/5.10.1/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.28.0/ppc-aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.8.8/ppc-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0
/usr/opt/perl5/lib
/usr/opt/perl5/lib/site_perl/5.10.1
/usr/opt/perl5/lib/site_perl/5.28.1
/usr/share/perl5/vendor_perl
/opt/freeware/lib/perl5/5.30/vendor_perl"
  else
    PPATH="/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi
/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0/ppc-aix-thread-multi
/usr/lib64/perl5
/opt/freeware/lib/perl5/vendor_perl/5.8.8
/opt/freeware/lib/perl5
/opt/freeware/lib/perl
/usr/opt/perl5/lib/site_perl
/usr/lib/perl5/vendor_perl
/usr/lib64/perl5/vendor_perl
/opt/csw/share/perl/csw
/usr/opt/perl5/lib/site_perl/5.10.1/aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.28.0/ppc-aix-thread-multi
/opt/freeware/lib/perl5/site_perl/5.8.8/ppc-thread-multi
/opt/freeware/lib/perl5/site_perl/5.22.0
/usr/opt/perl5/lib64/5.28.1
/usr/opt/perl5/lib64/5.28.0
/usr/opt/perl5/lib64
/usr/opt/perl5/lib
/usr/opt/perl5/lib/site_perl/5.10.1
/usr/opt/perl5/lib/site_perl/5.28.1
/usr/share/perl5/vendor_perl
/opt/freeware/lib/perl5/5.30/vendor_perl
/opt/freeware/lib64/perl5/5.30/vendor_perl
/usr/opt/perl5/lib64/site_perl"
  fi
fi

# /opt/csw/share/perl/csw is necessary on Solaris

if [ "$PERL_act" = "__PERL__" ]; then
  PERL_act="/usr/bin/perl"
fi

if [ ! -f $PERL_act ]; then
  echo "ERROR: Perl has not been found here: $PERL_act"
  echo "adjust right Perl path in etc/$wlabel.cfg"
fi

perl_version=`$PERL_act -v| grep "This is perl"| sed -e 's/^.* (v//' -e 's/) .*//' -e 's/^.* v//' -e 's/ .*//'`
perl_subversion=`$PERL_act -v| grep "This is perl"| sed -e 's/^.* (v//' -e 's/) .*//' -e 's/^.* v//' -e 's/ .*//' -e 's/\.[0-9][0-9]$//' -e 's/\.[0-9]$//' `

PLIB=`for ppath in $PPATH
do
  echo $PERL5LIB|grep "$ppath/$perl_version"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_version" ]; then
    echo "$ppath/$perl_version"
    echo "$ppath/$perl_version/vendor_perl"
    if [ $os_aix -eq 1 ]; then
      if [ $bit64 -eq 0 ]; then
        echo "$ppath/$perl_version/ppc-aix-thread-multi"
        echo "$ppath/$perl_version/aix-thread-multi"
      else
        echo "$ppath/$perl_version/aix-thread-multi-64all" # this must be behind 32bit!
      fi
    fi
  else
    echo $PERL5LIB|grep "$ppath"  >/dev/null
    if [ ! $? -eq 0  -a -d "$ppath" ]; then
      echo "$ppath"
    fi
  fi

  echo $PERL5LIB|grep "$ppath/$perl_subversion"  >/dev/null
  if [ ! $? -eq 0  -a -d "$ppath/$perl_subversion" ]; then
    echo "$ppath/$perl_subversion"
    echo "$ppath/$perl_subversion/vendor_perl"
    if [ $os_aix -eq 1 ]; then
      if [ $bit64 -eq 0 ]; then
        echo "$ppath/$perl_subversion/ppc-aix-thread-multi"
        echo "$ppath/$perl_subversion/aix-thread-multi"
      else
        echo "$ppath/$perl_subversion/aix-thread-multi-64all" # this must be behind 32bit!
      fi
    fi
  else
    echo $PERL5LIB|grep "$ppath"  >/dev/null
    if [ ! $? -eq 0  -a -d "$ppath" ]; then
      echo "$ppath"
    fi
  fi

done|xargs|sed -e 's/ /\:/g' -e 's/\:\:/\:/g'`


if [ `echo "$PERL5LIB"|grep aix-thread-multi|wc -l` -eq 0 ]; then
  PERL5LIB="$PERL5LIB:/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi"
fi
if [ `echo "$PERL5LIB"|grep ppc-thread-multi|wc -l` -eq 0 ]; then
  PERL5LIB="$PERL5LIB:/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi"
fi

# It must be close to the end
if [ -f /usr/opt/perl5/lib64/5.20.1 ]; then
  PERL5LIB="$PERL5LIB:/usr/opt/perl5/lib64/5.20.1"
fi

# It must be close to the end
if [ -f /usr/opt/perl5/lib64/site_perl/5.20.1 ]; then
  PERL5LIB="$PERL5LIB:/usr/opt/perl5/lib64/5.20.1"
fi

if [ $os_aix -gt 0 ]; then
  # AIX must have $HOMELPAR/lib on start due to https support
  if [ `echo "$PERL5LIB"|egrep "^$HOMELPAR/bin:$HOMELPAR/lib:" |wc -l` -eq 0 ]; then
    PERL5LIB="$HOMELPAR/bin:$HOMELPAR/lib:$PLIB:$PERL5LIB"
  fi
else
  if [ `echo "$PERL5LIB"|grep "$HOMELPAR/lib" |wc -l` -eq 0 ]; then
    PERL5LIB="$PLIB:$PERL5LIB:$HOMELPAR/lib"
  fi
fi

# Clean up PERL5LIB, place only existing dirs
PERL5LIB_new=""
for lib_path in `echo $PERL5LIB| sed 's/:/ /g'`
do
  if [ -d "$lib_path" ]; then
    if [ `echo "$PERL5LIB_new" | egrep "$lib_path:|$lib_path$" | wc -l | sed 's/ //g'` -eq 1 ]; then
      continue
    fi
    if [ `echo "$lib_path" | egrep "$HOMELPAR/bin$|/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi$|/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi$" | wc -l | sed 's/ //g'` -eq 1 ]; then
      # exclude $HOMELPAR/bin they will be added later on
      continue
    fi
    if [ "$PERL5LIB_new"x = "x" ]; then
      PERL5LIB_new=$lib_path
    else
      PERL5LIB_new=$PERL5LIB_new:$lib_path
    fi
  fi
done

if [ -d /usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi -a "$PERL_act" = "/opt/freeware/bin/perl" ]; then
  # /usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi must be before the others ontherwise problem with perl-Crypt-SSLeay and TLS 1...
  PERL5LIB=$HOMELPAR/bin:/opt/freeware/lib/perl5/vendor_perl/5.8.8/ppc-thread-multi:/usr/opt/perl5/lib/site_perl/5.8.8/aix-thread-multi:$PERL5LIB_new
else
  PERL5LIB=$HOMELPAR/bin:$PERL5LIB_new
fi


# it must be checked again as $HOMELPAR/lib do not have to exist yet if original version was squite old
if [ `echo "$PERL5LIB"|grep "$HOMELPAR/lib" |wc -l` -eq 0 ]; then
  PERL5LIB="$PERL5LIB:$HOMELPAR/lib"
fi

PERL5LIB=`echo "$PERL5LIB"|sed -e 's/::/:/g' -e 's/\//\\\\\\\\\//g' -e 's/ //g'`


if [ $DEBUG_UPD -eq 1 ]; then
  echo "
	$WEBDIR
	$HMC_USER
	$HMC_LIST
	$HMC_HOSTAME
	$MANAGED_SYSTEMS_EXCLUDE
	$PERL
	$RRDTOOL
	$SRATE
	$VER
	$WEBDIR_PLAIN
	$HWINFO
	$SYS_CHANG
	$RRDHEIGHT
	$RRDWIDTH
	$PERL5LIB
	$PICTURE_COLOR
	$DEBUG
  	$EXPORT_TO_CSV
  	$HEA
  	$STEP_HEA
  	$TOPTEN
  	$LPM
  	$LPM_LPAR_EXCLUDE
  	$LPM_SERVER_EXCLUDE
  	$LPM_HMC_EXCLUDE
  "
fi

# Original edition: free/full test
free_edition_org=1
if [ ! -f "$HOMELPAR/tmp/menu.txt" ]; then
  echo ""
  echo "Could not found $HOMELPAR/tmp/menu.txt, considering original edition as a Free one"
  echo ""
else
  if [ `egrep "^O:0:" "$HOMELPAR/tmp/menu.txt" | wc -l | sed 's/ //g'` -gt 0 ]; then
    # full version
    free_edition_org=0
  fi
fi

# New edition: free/full test
free_edition_new=1
if [ `echo $pwd| egrep -- "-full|-trial-"| wc -l|  sed 's/ //g'` -eq 1 ]; then
  # full version
  free_edition_new=0
fi
if [ ! "$WLABEL" = "STOR2RRD"  ]; then
  # full version always
  free_edition_new=0
  free_edition_org=0
fi


if [ $free_edition_org -eq 0 -a $free_edition_new -eq 1 ]; then
  echo ""
  echo "You are going to install the Free edition over the Enterprise edition!!!"
  echo "Enterprise edition features will be deleted from your instance:"
  echo "Type enter to continue, Ctrl-C to interrupt it"
  # check if it is running from the image, then no wait for the input
  if [ "$VM_IMAGE"x = "x" ]; then
    read full
  else
    if [ $VM_IMAGE -eq 0 ]; then
      read full
    else
      echo "yes"
      full="yes"
    fi
  fi
  rm -f $HOMELPAR/bin/premium.* $HOMELPAR/load_data.sh $HOMELPAR/bin/offsite.sh $HOMELPAR/bin/reporter-premium.pl
  rm -f $HOMELPAR/html/hist_reports* $HOMELPAR/www/hist_reports* $WEBDIR/hist_reports*
  rm -f $HOMELPAR/stor2rrd-cgi/stor2rrd-cgi.sh $HOMELPAR/bin/stor2rrd-cgi.pl
  rm -f $HOMELPAR/bin/genreport.sh
  echo "Enterprise edition features have been deleted."
fi

if [ $free_edition_new -eq 1 ]; then
  rm -f $HOMELPAR/bin/premium.* $HOMELPAR/load_data.sh $HOMELPAR/bin/offsite.sh $HOMELPAR/bin/reporter-premium.pl
  rm -f $HOMELPAR/html/hist_reports* $HOMELPAR/www/hist_reports* $WEBDIR/hist_reports*
  rm -f $HOMELPAR/stor2rrd-cgi/stor2rrd-cgi.sh $HOMELPAR/bin/stor2rrd-cgi.pl
  rm -f $HOMELPAR/bin/genreport.sh
fi

echo "Backing up original version : $version to $HOMELPAR/BACKUP-INSTALL/$wlabel-$version"
if [ ! -d $HOMELPAR/BACKUP-INSTALL ]; then
  mkdir $HOMELPAR/BACKUP-INSTALL
fi
if [ ! -d $HOMELPAR/BACKUP-INSTALL/$wlabel-$version ]; then
  mkdir $HOMELPAR/BACKUP-INSTALL/$wlabel-$version
fi

# Do not save old logs, they are for nothing ...
echo "Saving actual configuration"
#cp -R $HOMELPAR/logs $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/ 2>/dev/null
if [ -f "$HOMELPAR/logs/alert_history.log" ]; then
  cp -f $HOMELPAR/logs/alert_history.log $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/alert_history.log
fi
if [ -f "$HOMELPAR/logs/alert_event_history.log" ]; then
  cp -f $HOMELPAR/logs/alert_event_history.log $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/alert_event_history.log
fi
rm -f $HOMELPAR/logs/* 2>/dev/null # clean up logs
if [ -f "$HOMELPAR/BACKUP-INSTALL/$wlabel-$version/alert_history.log" ]; then
  # keep alert_history.log through upgrades
  mv $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/alert_history.log $HOMELPAR/logs/
fi
if [ -f "$HOMELPAR/BACKUP-INSTALL/$wlabel-$version/alert_event_history.log" ]; then
  # keep alert_event_history.log through upgrades
  mv $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/alert_event_history.log $HOMELPAR/logs/
fi
#gzip -f9 $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/logs/* 1>/dev/null 2>&1 #compress old logs

cp -Rp $HOMELPAR/etc $HOMELPAR/bin $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/ 2>/dev/null
cp -p $HOMELPAR/*.cfg $HOMELPAR/*.txt $HOMELPAR/*.sh $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/ 2>/dev/null
mv $HOMELPAR/*.sh $HOMELPAR/*.pl $HOMELPAR/*.pm $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/ 2>/dev/null
mv $HOMELPAR/$wlabel-[1-9]* $HOMELPAR/BACKUP-INSTALL/  2>/dev/null # move away old backups


#cp $HOMELPAR/etc/stor2rrd.cfg $HOMELPAR/etc/stor2rrd.cfg-org
cp -Rp $HOMELPAR/html $HOMELPAR/$wlabel-cgi $HOMELPAR/bin $HOMELPAR/BACKUP-INSTALL/$wlabel-$version/ 2>/dev/null

# save cfg
mv $HOMELPAR/etc/storage-list.cfg $HOMELPAR/etc/storage-list.cfg-org
if [ -f $HOMELPAR/etc/san-list.cfg ]; then
  mv $HOMELPAR/etc/san-list.cfg $HOMELPAR/etc/san-list.cfg-org # since 1.14
fi
if [ -f $HOMELPAR/etc/lan-list.cfg ]; then
  mv $HOMELPAR/etc/lan-list.cfg $HOMELPAR/etc/lan-list.cfg-org
fi
mv $HOMELPAR/etc/alias.cfg $HOMELPAR/etc/alias.cfg-org

if [ -f $HOMELPAR/etc/storage-groups.cfg ]; then
  mv $HOMELPAR/etc/storage-groups.cfg $HOMELPAR/etc/storage-groups.cfg-org # since 2.45
fi


# stopping svcperf.pl processes (SVC/Storwize)
if [ `ps -ef|grep svcperf.pl|grep perl|$AWK '{print $2}'|wc -l ` -gt 0 ]; then
  kill `ps -ef|grep svcperf.pl|grep perl|$AWK '{print $2}'|xargs`
  sleep 1
fi
# stopping dothillperf.pl processes (DotHill)
if [ `ps -ef|grep dothillperf.pl|grep perl|$AWK '{print $2}'|wc -l ` -gt 0 ]; then
  kill `ps -ef|grep dothillperf.pl|grep perl|$AWK '{print $2}'|xargs`
  sleep 1
fi

# Clean up html/jquery/* a www/jquery/*   before upgrade from old stuff
rm -rf $HOMELPAR/html/jquery/*  $WEBDIR_PLAIN/jquery/* $HOMELPAR/html/css/*  $WEBDIR_PLAIN/css/*

echo "Copy new version to the target destination"
chmod 644 $HOMELPAR/lib/*pm 2>/dev/null # was some problem in past
cp -R * $HOMELPAR/

# Copy web files directly, do not wait for next load.sh
cp $HOMELPAR/html/*pdf $HOMELPAR/html/*html $HOMELPAR/html/*ico $HOMELPAR/html/*png $WEBDIR_PLAIN/
pwd_org=`pwd`
cd $HOMELPAR/html
tar cf - jquery css | (cd $WEBDIR_PLAIN ; tar xf - )
cd $pwd_org
chown -R $ID $HOMELPAR/html $WEBDIR_PLAIN
chmod -R 755 $HOMELPAR/html $WEBDIR_PLAIN # must be due tue subdirs jquery, images ...

if [ $os_aix -gt 0 ]; then
  # extract perl lib for https REST API support (LWP 6.06)
  if [ -f ../perl_aix_ssl.tar.Z ]; then
    uncompress -f ../perl_aix_ssl.tar.Z
  fi
  if [ -f ../perl_aix_ssl.tar ]; then
    tar xf ../perl_aix_ssl.tar
    cp -R lib $HOMELPAR/
  else
    echo "ERROR during: uncompress -f perl_aix_ssl.tar.Z : install it manually"
    echo "  uncompress -f perl_aix_ssl.tar.Z; cd $HOMELPAR/; tar xvf perl_aix_ssl.tar"
  fi
fi

COLLECTOR=0
if [ ! -f "$HOMELPAR/etc/.magic" -a -f "$HOMELPAR/etc/.magic-install" ]; then
  mv "$HOMELPAR/etc/.magic-install" "$HOMELPAR/etc/.magic"
  chmod 644 "$HOMELPAR/etc/.magic"
fi
if [ -f "$HOMELPAR/etc/.magic" ]; then
  . "$HOMELPAR/etc/.magic"
  if [ ! "$DO_NOT_SAVE_DATA"x = "x" ]; then
    if [ $DO_NOT_SAVE_DATA -eq 1 ]; then
      COLLECTOR=1
    fi
  fi
fi

if [ $COLLECTOR -eq 0 ]; then
  if [ ! -f "$HOMELPAR/tmp/menu.txt" -a -f "$HOMELPAR/html/menu_default.txt" ]; then
    #place default menu.txt
    cp $HOMELPAR/html/menu_default.txt $HOMELPAR/tmp/menu.txt
  fi
fi


echo "Configuring new $wlabel.cfg"
eval ' sed -e 's/WEBDIR=.*/WEBDIR=$WEBDIR/g' \
           -e 's/RRDTOOL=.*/RRDTOOL=$RRD/g' -e 's/SAMPLE_RATE=.*/SAMPLE_RATE=$SAMPLE_RATE/g' \
           -e 's/DS8_USER=.*/DS8_USER=$DS8_USER/g' -e 's/DS8_CLIDIR=.*/DS8_CLIDIR=$DS8_CLIDIR/g' \
           -e 's/DS5_CLIDIR=.*/DS5_CLIDIR=$DS5_CLIDIR/g' -e 's/HUS_CLIDIR=.*/HUS_CLIDIR=$HUS_CLIDIR/g' \
	   -e 's/PERL=.*/PERL=$PERL/g' -e 's/RRDHEIGHT=.*/RRDHEIGHT=$RRDHEIGHT/g' \
	   -e 's/RRDWIDTH=.*/RRDWIDTH=$RRDWIDTH/g' -e 's/PERL5LIB=.*/PERL5LIB=$PERL5LIB/g' \
           -e 's/DASHB_RRDHEIGHT=.*/DASHB_RRDHEIGHT=$DASHB_RRDHEIGHT/g' -e 's/DASHB_RRDWIDTH=.*/DASHB_RRDWIDTH=$DASHB_RRDWIDTH/g' \
	   -e 's/PICTURE_COLOR=.*/PICTURE_COLOR=$PICTURE_COLOR/g' -e 's/DEBUG=.*/DEBUG=$DEBUG/g' \
	   -e 's/TOPTEN=.*/TOPTEN=$TOPTEN/g' -e 's/ERRLOG=.*/ERRLOG=$ERRLOG/g' \
	   -e 's/VOLUME_RESPONSE_MAX=.*/VOLUME_RESPONSE_MAX=$VOLUME_RESPONSE_MAX/g' \
	   -e 's/VOLUME_IO_MAX=.*/VOLUME_IO_MAX=$VOLUME_IO_MAX/g' -e 's/UNITY_CLIDIR=.*/UNITY_CLIDIR=$UNITY_CLIDIR/g' \
	   -e 's/VOLUME_CACHE_MAX=.*/VOLUME_CACHE_MAX=$VOLUME_CACHE_MAX/g'  -e 's/VNXE_CLIDIR=.*/VNXE_CLIDIR=$VNXE_CLIDIR/g' \
	   -e 's/VOLUME_DATA_MAX=.*/VOLUME_DATA_MAX=$VOLUME_DATA_MAX/g' \
	   -e 's/STORAGE_USER=.*/STORAGE_USER=$STORAGE_USER/g' -e 's/LEGEND_HEIGHT=.*/LEGEND_HEIGHT=$LEGEND_HEIGHT/g' \
           -e 's/SAN_CFG=.*/SAN_CFG=$SAN_CFG/g' -e 's/VSP_CLIDIR=.*/VSP_CLIDIR=$VSP_CLIDIR/g' \
           -e 's/HPE3PAR_CLIDIR=.*/HPE3PAR_CLIDIR=$HPE3PAR_CLIDIR/g' \
           -e 's/VNX_BLOCK_CLIDIR=.*/VNX_BLOCK_CLIDIR=$VNX_BLOCK_CLIDIR/g' -e 's/PDF_PAGE_SIZE=.*/PDF_PAGE_SIZE=$PDF_PAGE_SIZE/g' \
           -e 's/HDS_EXPORT_TOOL_JAVAPATH=.*/HDS_EXPORT_TOOL_JAVAPATH=$HDS_EXPORT_TOOL_JAVAPATH/g' -e 's/SSH=.*/SSH=$SSH/g' \
           -e 's/WEB_CGI_PATH=.*/WEB_CGI_PATH=$WEB_CGI_PATH/g' -e 's/LAN_CFG=.*/LAN_CFG=$LAN_CFG/g' \
       	   -e 's/STORAGE_CFG=.*/STORAGE_CFG=$STORAGE_CFG/g' $CFG > $CFG-new '
if [ `cat $CFG-new|wc -l|sed 's/ //g'`  -eq 0 ]; then
  echo ""
  echo "ERROR: Configuration of $CFG failed, original file is kept"
  echo "       This might cause unpredictable problems, contact product support in case anything is not working fine after the update"
  echo ""
  cp $CFG-backup $CFG
else
  mv $CFG-new $CFG
fi
rm -f $CFG-backup

if [ "$WLABEL" = "BREAKPOINT" ]; then
  # etc/.magic again loads WLABEL
  WLABEL=STOR2RRD
fi

ed $CFG << EOF 2>/dev/null 1>&2
g/^STOR2RRD home :/s/^STOR2RRD home : http.*$//g
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
w
q
EOF

if [ ! -f $HOMELPAR/etc/heatmap-color.cfg ]; then
  mv $HOMELPAR/etc/heatmap-color.cfg-default  $HOMELPAR/etc/heatmap-color.cfg
fi


if [ $aix_libpath -eq 0 ]; then
  # comment out LIBPATH on AIX to avoid including /opt/freeware/bin which can cause a problem in some situations
ed $CFG << EOF 2>/dev/null 1>&2
g/export LIBPATH=/s/export LIBPATH=/#export LIBPATH=/g
g/  LIBPATH=/s/  LIBPATH=/ #LIBPATH=/g
w
q
EOF
fi

if [ -f $HOMELPAR/etc/web_config/alerting.cfg ]; then
  # change alerting peak time to 30 minutes (to be save)
ed $HOMELPAR/etc/web_config/alerting.cfg << EOF 2>/dev/null 1>&2
g/PEAK_TIME_DEFAULT=/s/PEAK_TIME_DEFAULT=.*/PEAK_TIME_DEFAULT=30/g
w
q
EOF
fi

if [ ! "$WLABEL" = "STOR2RRD" ]; then
  echo "White labeling cgi-bin for $WLABEL/$wlabel"
  # cgi-bin for white labeling stuff, it must be before White Label cleaning!!!
  if [ ! -d $HOMELPAR/$wlabel-cgi -a -d $HOMELPAR/stor2rrd-cgi ]; then
    mv $HOMELPAR/stor2rrd-cgi $HOMELPAR/$wlabel-cgi
  fi
  if [ -d $HOMELPAR/$wlabel-cgi -a -d $HOMELPAR/stor2rrd-cgi ]; then
    mv $HOMELPAR/stor2rrd-cgi/* $HOMELPAR/$wlabel-cgi
    mv $HOMELPAR/$wlabel-cgi/stor2rrd-cgi.sh $HOMELPAR/$wlabel-cgi/$wlabel-cgi.sh
    rm -rf $HOMELPAR/stor2rrd-cgi/
  fi
fi

#
# White Label cleaning
#

if [ ! "$WLABEL" = "STOR2RRD" ]; then
  rm -f $HOMELPAR/README
  if [ -f $HOMELPAR/bin/check_stor2rrd ]; then
    mv $HOMELPAR/bin/check_stor2rrd $HOMELPAR/bin/check_$wlabel
  fi

for i in $HOMELPAR/html/*.html $HOMELPAR/html/jquery/main.js $HOMELPAR/bin/*
do
  ed $i << EOF >/dev/null 2>&1
g/logo-stor2rrd/s/logo-stor2rrd/logo-$wlabel/g
g/STOR2RRD HOME/s/STOR2RRD HOME/$WLABEL HOME/g
g/STOR2RRD website/s/STOR2RRD website/$WLABEL website/g
g/STOR2RRD cookies/s/STOR2RRD cookies/$WLABEL cookies/g
g/STOR2RRD edition/s/STOR2RRD edition/$WLABEL edition/g
g/STOR2RRD version/s/STOR2RRD version/$WLABEL version/g
g/http:\/\/www\.stor2rrd\.com\/.*.html/s/http:\/\/www\.stor2rrd\.com\/.*.html/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/http:\/\/www\.stor2rrd\.com\/.*.htm/s/http:\/\/www\.stor2rrd\.com\/.*.htm/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/http:\/\/www\.stor2rrd\.com\/.*.pdf/s/http:\/\/www\.stor2rrd\.com\/.*.pdf/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/http:\/\/www\.stor2rrd\.com\/.*.csv/s/http:\/\/www\.stor2rrd\.com\/.*.csv/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/http:\/\/www\.stor2rrd\.com\/.*.zip/s/http:\/\/www\.stor2rrd\.com\/.*.zip/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.html/s/https:\/\/www\.stor2rrd\.com\/.*.html/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.htm/s/https:\/\/www\.stor2rrd\.com\/.*.htm/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.pdf/s/https:\/\/www\.stor2rrd\.com\/.*.pdf/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.csv/s/https:\/\/www\.stor2rrd\.com\/.*.csv/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/https:\/\/www\.stor2rrd\.com\/.*.zip/s/https:\/\/www\.stor2rrd\.com\/.*.zip/https:\/\/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
w
q
EOF
done

for i in $HOMELPAR/html/jquery/main.js
do
  ed $i << EOF >/dev/null 2>&1
g/www.xorux.com/s/www.xorux.com/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/>XORUX</s/>XORUX</>$WLABEL_COMPANY</g
w
q
EOF
done

for i in $HOMELPAR/html/jquery/main.js
do
  ed $i << EOF >/dev/null 2>&1
g/www.xorux.com/s/www.xorux.com/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/www.stor2rrd.com/s/www.stor2rrd.com/www\.$wlabel_company\.$wlabel_domain\/$wlabel_docu/g
g/>XORUX</s/>XORUX</>$WLABEL</g
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
w
q
EOF
done

for i in $HOMELPAR/bin/AlertStor2rrd.pm
do
  ed $i << EOF >/dev/null 2>&1
g/stor2rrd-alert-/s/stor2rrd-alert-/$wlabel-alert-</g
w
q
EOF
done


for i in $HOMELPAR/$wlabel-cgi/genpdf.sh $HOMELPAR/$wlabel-cgi/heatmapcfg.sh 
do
  ed $i << EOF >/dev/null 2>&1
g/APPNAME="stor2rrd"/s/APPNAME="stor2rrd"/APPNAME="$wlabel"/g
w
q
EOF
done

for i in $HOMELPAR/*.sh
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
w
q
EOF
done

for i in $HOMELPAR/bin/*.sh
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/stor2rrd-realt-error/s/stor2rrd-realt-error/$wlabel-realt-error/g
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
g/stor2rrd-cgi\.sh//s/stor2rrd-cgi\.sh//$wlabel-cgi\.sh//g
w
q
EOF
done

for i in $HOMELPAR/$wlabel-cgi/*.sh
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/stor2rrd-realt-error/s/stor2rrd-realt-error/$wlabel-realt-error/g
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
g/stor2rrd-cgi\.sh/s/stor2rrd-cgi\.sh/$wlabel-cgi\.sh/g
w
q
EOF
done

for i in $HOMELPAR/html/* $HOMELPAR/etc/links.json
do
  ed $i << EOF >/dev/null 2>&1
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
g/stor2rrd-cgi\.sh/s/stor2rrd-cgi\.sh/$wlabel-cgi\.sh/g
g/\/stor2rrd-cgi\"/s/\/stor2rrd-cgi\"/\/$wlabel-cgi\"/g
w
q
EOF
done

for i in $HOMELPAR/bin/*.pl 
do
  ed $i << EOF >/dev/null 2>&1
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
g/www\.stor2rrd\.com/s/www\.stor2rrd\.com/www\.$wlabel\.com/g
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/>STOR2RRD</s/>STOR2RRD</>$WLABEL</g
g/TITLE>STOR2RRD</s/TITLE>STOR2RRD</TITLE>$WLABEL</g
g/title>STOR2RRD</s/title>STOR2RRD</title>$WLABEL</g
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
w
q
EOF
done

for i in $HOMELPAR/bin/*
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD_HOME/s/STOR2RRD_HOME/$WLABEL_HOME/g
g/LPAR2RRD_HOME/s/LPAR2RRD_HOME/$WLABEL_HOME/g
g/check_stor2rrd/s/check_stor2rrd/check_$wlabel/g
w
q
EOF
done

for i in $HOMELPAR/bin/*.pm
do
  ed $i << EOF >/dev/null 2>&1
g/stor2rrd-cgi\//s/stor2rrd-cgi\//$wlabel-cgi\//g
g/stor2rrd\.cfg/s/stor2rrd\.cfg/$wlabel\.cfg/g
g/www\.stor2rrd\.com/s/www\.stor2rrd\.com/www\.$wlabel\.com/g
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
g/TITLE>STOR2RRD</s/TITLE>STOR2RRD</TITLE>$WLABEL</g
g/cgiPath="\/stor2rrd-cgi"/s/cgiPath="\/stor2rrd-cgi"/cgiPath="\/$wlabel-cgi"/g
w
q
EOF
done

for i in $HOMELPAR/etc/storage-list.cfg*
do
  ed $i << EOF >/dev/null 2>&1
g/#  --> Check http/s/#  --> Check http.*$//g
w
q
EOF
done

for i in $HOMELPAR/etc/web_config/*
do
  ed $i << EOF >/dev/null 2>&1
g/STOR2RRD /s/STOR2RRD /$WLABEL /g
w
q
EOF
done

ed $HOMELPAR/html/support_logs.html << EOF >/dev/null 2>&1
g/stor2rrd/s/stor2rrd/$wlabel/g
w
q
EOF

fi


# save last template
mv $HOMELPAR/etc/storage-list.cfg $HOMELPAR/etc/storage-list.cfg.example
if [ -f $HOMELPAR/etc/san-list.cfg-org ]; then
  mv $HOMELPAR/etc/san-list.cfg $HOMELPAR/etc/san-list.cfg.example
fi
if [ -f $HOMELPAR/etc/lan-list.cfg-org ]; then
  mv $HOMELPAR/etc/lan-list.cfg $HOMELPAR/etc/lan-list.cfg.example
fi
mv $HOMELPAR/etc/alias.cfg $HOMELPAR/etc/alias.cfg.example

# return cfg
mv $HOMELPAR/etc/storage-list.cfg-org $HOMELPAR/etc/storage-list.cfg
if [ -f $HOMELPAR/etc/san-list.cfg-org ]; then
  mv $HOMELPAR/etc/san-list.cfg-org $HOMELPAR/etc/san-list.cfg
fi
if [ -f $HOMELPAR/etc/lan-list.cfg-org ]; then
  mv $HOMELPAR/etc/lan-list.cfg-org $HOMELPAR/etc/lan-list.cfg
fi
if [ -f $HOMELPAR/etc/storage-groups.cfg-org ]; then
  mv $HOMELPAR/etc/storage-groups.cfg-org $HOMELPAR/etc/storage-groups.cfg
fi
mv $HOMELPAR/etc/alias.cfg-org $HOMELPAR/etc/alias.cfg

if [ `grep SANPORT $HOMELPAR/etc/alias.cfg 2>/dev/null| wc -l | sed 's/ //g'` -eq 0 ]; then
  echo "#" >> $HOMELPAR/etc/alias.cfg
  echo "# for SAN switches:" >> $HOMELPAR/etc/alias.cfg
  echo "#SANPORT:switch_name:port_name:your_alias" >> $HOMELPAR/etc/alias.cfg
  echo "#SANPORT:SAN-switch1:2:ALIAS_for_port2" >> $HOMELPAR/etc/alias.cfg
fi

if [ `grep SNMP_PORT $HOMELPAR/etc/san-list.cfg 2>/dev/null| wc -l | sed 's/ //g'` -eq 0 ]; then
  echo "#" >> $HOMELPAR/etc/san-list.cfg
  echo "# Define your SNMP port If you using another then default 161" >> $HOMELPAR/etc/san-list.cfg
  echo "#SNMP_PORT=161" >> $HOMELPAR/etc/san-list.cfg
  echo "#" >> $HOMELPAR/etc/san-list.cfg
fi

# must be removed here before chown ...
rm -f $HOMELPAR/realt-error.log
rm -f $HOMELPAR/logs/error-cgi.log

echo "Setting file/dir permissions, it might take some time in huge environments"
chown $ID $HOMELPAR
if [ ! $? -eq 0 ]; then
  echo "Problem with ownership of $HOMELPAR"
  echo "Fix it and run it again : chown  $ID $HOMELPAR"
  exit 1
fi

chown $ID $HOMELPAR/* 2>&1|egrep -v "error-cgi|lost+found"
chown -R $ID $HOMELPAR/$wlabel-cgi
chown -R $ID $HOMELPAR/MIBs
chown $ID $HOMELPAR/etc
chown $ID $HOMELPAR/etc/*.cfg
chown $ID $HOMELPAR/etc/*.txt
chown -R $ID $HOMELPAR/logs 2>&1|egrep -v "error-cgi|HORCM"
chown -R $ID $HOMELPAR/scripts 2>/dev/null
chown -R $ID $HOMELPAR/www   2>/dev/null
if [ ! -d $HOMELPAR/tmp ]; then
  mkdir $HOMELPAR/tmp
fi
if [ "$VM_IMAGE"x = "x" ]; then
  chmod 777 $HOMELPAR/tmp  # due to Xormon which needs to save temp files there
else
  chmod 755 $HOMELPAR/tmp  # not necessary on the image
fi
chmod -R 755 $HOMELPAR/lib
chmod 644 $HOMELPAR/lib/*pm
chmod 755 $HOMELPAR/logs
chmod 755 $HOMELPAR/MIBs
chmod 666 $HOMELPAR/logs/* 2>&1|egrep -v "error-cgi|HORCM"
chmod 755 $HOMELPAR
chmod 755 $HOMELPAR/bin
chmod 755 $HOMELPAR/dbschema
chmod -R 755 $HOMELPAR/$wlabel-cgi
chmod -R o+r $HOMELPAR/www  2>/dev/null
chmod -R o+x $HOMELPAR/www 2>/dev/null
chmod 755 $HOMELPAR/bin/*.pl
chmod 755 $HOMELPAR/bin/*.py
chmod 755 $HOMELPAR/bin/*.pm
chmod 755 $HOMELPAR/bin/*.sh
chmod 755 $HOMELPAR/*.sh
chmod 755 $HOMELPAR/etc
# do not touch etc/web_config here!
chmod 644 $HOMELPAR/dbschema/*
chmod 644 $HOMELPAR/etc/*.cfg
chmod 644 $HOMELPAR/etc/*.txt
chmod 644 $HOMELPAR/MIBs/*
chmod 755 $HOMELPAR/scripts/* 2>/dev/null
chmod 644 $HOMELPAR/*.txt 2>/dev/null
if [ -f "$HOMELPAR/.magic" ]; then
  chown $ID $HOMELPAR/.magic 2>&1
  chmod 755 $HOMELPAR/.magic 2>&1
fi

if [ ! -d "$HOMELPAR/etc/web_config" ]; then
  mkdir "$HOMELPAR/etc/web_config"
fi
if [ "$VM_IMAGE"x = "x" ]; then
  chmod 777 "$HOMELPAR/etc/web_config"
  chmod 777 "$HOMELPAR/reports"
else
  chmod 755 "$HOMELPAR/etc/web_config"
  chmod 755 "$HOMELPAR/reports"
fi

if [ "$VM_IMAGE"x = "x" ]; then
  # only for non image update, it might take a long time and on image should not happen such things
  #echo "chown -R $ID $HOMELPAR/data"
  #chown -R $ID $HOMELPAR/data  2>&1|egrep -v " path name does not exist|No such file or directory"
  echo "chmod -R o+r,o+x $HOMELPAR/data"
  chmod -R o+r,o+x $HOMELPAR/data 2>&1|egrep -v " path name does not exist|No such file or directory"
  #echo "chmod -R o+x $HOMELPAR/data"
  #chmod -R o+x $HOMELPAR/data 2>&1|egrep -v " path name does not exist|No such file or directory"
  echo ""
fi

if [ "$VM_IMAGE"x = "x" ]; then
  chmod 644 $HOMELPAR/etc/storage-list.cfg # passwords might be inside!
else
  chmod 600 $HOMELPAR/etc/storage-list.cfg # passwords might be inside!
fi

if [ ! -h $HOMELPAR/logs/error-cgi.log ]; then
  ln -s /var/tmp/$wlabel-realt-error.log $HOMELPAR/logs/error-cgi.log 2>/dev/null
fi
if [ -f /var/tmp/$wlabel-realt-error.log ]; then
  # remove cgi-bin error log if rights are sufficient
  cat /dev/null > /var/tmp/$wlabel-realt-error.log 2>/dev/null
fi



cd $HOMELPAR

if [ ! -d "$WEBDIR_PLAIN" ]; then
  mkdir "$WEBDIR_PLAIN"
fi

if [ ! -d "$WEBDIR_PLAIN" ]; then
  mkdir "$WEBDIR_PLAIN"
fi

if [ ! -d "$HOMELPAR/etc/web_config" ]; then
  mkdir "$HOMELPAR/etc/web_config"
fi
if [ "$VM_IMAGE"x = "x" ]; then
  chmod 777 "$HOMELPAR/etc/web_config"
else
  chmod 755 "$HOMELPAR/etc/web_config"
fi


if [ ! -f "$HOMELPAR/etc/web_config/htusers.cfg" ]; then
  echo 'admin:$apr1$CSoXefyw$wGe9K7Ld5ClOEozE4zC.T1' >  $HOMELPAR/etc/web_config/htusers.cfg
  if [ "$VM_IMAGE"x = "x" ]; then
    chmod 666 $HOMELPAR/etc/web_config/htusers.cfg
  else
    chmod 600 $HOMELPAR/etc/web_config/htusers.cfg
  fi
fi




if [ "$VM_IMAGE"x = "x" ]; then # test it only if it is not running from the image
  # Check whether web user has read&executable rights for CGI dir stor2rrd-cgi
  www=`echo "$WEBDIR"|sed 's/\\\//g'`
  DIR=""
  IFS_ORG=$IFS
  IFS="/"
  for i in $www
  do
    IFS=$IFS_ORG
    NEW_DIR=`echo $DIR$i/`
    #echo "01 $NEW_DIR -- $i -- $DIR ++ $www"
    NUM=`ls -dLl $NEW_DIR |$AWK '{print $1}'|sed -e 's/d//g' -e 's/-//g' -e 's/w//g' -e 's/\.//g'| wc -c`
    #echo "02 $NUM"
    if [ ! $NUM -eq 7 ]; then
      echo ""
      echo "WARNING, directory : $NEW_DIR has probably wrong rights" | sed 's/\/\//\//g'
      echo "         $www dir and its subdirs have to be executable&readable for WEB user"
      ls -lLd $NEW_DIR| sed 's/\/\//\//g'
      echo ""
    fi
    DIR=`echo "$NEW_DIR/"`
    #echo $DIR
    IFS="/"
  done
  IFS=$IFS_ORG


  # Check whether web user has read&executable rights for CGI dir stor2rrd-cgi
  CGI="$HOMELPAR/$wlabel-cgi"
  DIR=""
  IFS_ORG=$IFS
  IFS="/"
  for i in $CGI
  do
    IFS=$IFS_ORG
    NEW_DIR=`echo $DIR$i/`
    NUM=`ls -dLl $NEW_DIR |$AWK '{print $1}'|sed -e 's/d//g' -e 's/-//g' -e 's/w//g' -e 's/\.//g'| wc -c`
    #echo $NUM
    if [ ! $NUM -eq 7 ]; then
      echo ""
      echo "WARNING, directory : $NEW_DIR has probably wrong rights" | sed 's/\/\//\//g'
      echo "         it dir has to be executable&readable for WEB user"
      ls -lLd $NEW_DIR| sed 's/\/\//\//g'
      echo ""
    fi
    DIR=`echo "$NEW_DIR/"`
    #echo $DIR
    IFS="/"
  done
  IFS=$IFS_ORG
fi


rm -f $HOMELPAR/tmp/[1-9]* 2>/dev/null # do not remove everything as usually, topten files should stay


# change #!bin/ksh in shell script to #!bin/bash on Linux platform
os_linux=` uname -s|egrep "^Linux$"|wc -l|sed 's/ //g'`
if [ $os_linux -gt 0 ]; then
  # If Linux then change all "#!bin/sh --> #!bin/bash
  for sh in $HOMELPAR/bin/*.sh
  do
  ed $sh << EOF 2>/dev/null 1>&2
1s/\/ksh/\/bash/
w
q
EOF
  done

  for sh in $HOMELPAR/*.sh
  do
  ed $sh << EOF 2>/dev/null 1>&2
1s/\/ksh/\/bash/
w
q
EOF
  done

  for sh in $HOMELPAR/$wlabel-cgi/*.sh
  do
  ed $sh << EOF 2>/dev/null 1>&2
1s/\/ksh/\/bash/
w
q
EOF
  done

else
  # for AIX Solaris etc, all should be already in place just to be sure ...
  # change all "#!bin/bash --> #!bin/ksh
  for sh in $HOMELPAR/bin/*.sh
  do
  ed $sh << EOF 2>/dev/null 1>&2
1s/\/bash/\/ksh/
w
q
EOF
  done

  for sh in $HOMELPAR/*.sh
  do
  ed $sh << EOF 2>/dev/null 1>&2
1s/\/bash/\/ksh/
w
q
EOF
  done

  for sh in $HOMELPAR/$wlabel-cgi/*.sh
  do
  ed $sh << EOF 2>/dev/null 1>&2
1s/\/bash/\/ksh/
w
q
EOF
  done

fi


# Custom groups
# Refresh custom restriction after the upgrade
rm -f $HOMELPAR/tmp/custom-group/.*-ll.cmd

# remove custom cmd definitions to be sure that they are reinitiated after upgrade,
if [ ! "$DEMO"x = "x" ]; then
   if [ $DEMO -eq 0 ]; then
     rm -f $HOMELPAR/tmp/custom-group/*cmd
   fi
else
  rm -f $HOMELPAR/tmp/custom-group/*cmd
fi



if [  $COLLECTOR -eq 0 ]; then

  # ulimit check
  # necessary for big aggregated graphs
  #
  # AIX (chuser saves it in blocks) :
  # chuser  data=8388608  lpar2rrd (4GB)
  # chuser  stack=1048576 lpar2rrd (512MB)

  ulimit_message=0
  data=`ulimit -d`
  stack=`ulimit -s`
  if [ $os_aix -eq 1 ]; then
    if [ ! "$data" = "unlimited" -a ! "$data" = "hard" -a ! "$data" = "soft" ]; then
      if [ $data -lt 4194304 ]; then
        echo ""
        echo "Warning: increase data ulimit for $ID user, it is actually too low ($data kB)"
        echo "Assure that the same limits has even the web user (apache/nobody/http)"
        echo "  under root: chuser  data=8388608 $ID # 4GB"
      fi
    fi
    if [ ! "$stack" = "unlimited" -a ! "$stack" = "hard" -a ! "$data" = "soft" ]; then
      if [ $stack -lt 524288  ]; then
        echo ""
        echo "Warning: increase stack ulimit for $ID user, it is actually too low ($stack kB)"
        echo "Assure that the same limits has even the web user (apache/nobody/http)"
        echo "  under root: chuser  stack=1048576 $ID # 512MB"
      fi
    fi
  else # Linux
    if [ ! "$data" = "unlimited" -a ! "$data" = "hard" -a ! "$data" = "soft" ]; then
      if [ $data -lt 4194304 ]; then
        echo ""
        echo "Warning: increase data ulimit for $ID user, it is actually too low ($data kB)"
        echo "Assure that the same limits has even the web user (apache/nobody/http)"
        echo "  under root: vi /etc/security/limits.conf and set 4GB"
        echo "    @$ID        hard    data            4194304"
        echo "    @$ID        soft    data            4194304"
      fi
    fi
    if [ ! "$stack" = "unlimited" -a ! "$stack" = "hard" -a ! "$data" = "soft" ]; then
      if [ $stack -lt 524288  ]; then
        echo ""
        echo "Warning: increase stack ulimit for $ID user, it is actually too low ($stack kB)"
        echo "Assure that the same limits has even the web user (apache/nobody/http)"
        echo "  under root: vi /etc/security/limits.conf and set 512 MB"
        echo "    @$ID        hard    stack           524288"
        echo "    @$ID        soft    stack           524288"
      fi
    fi
  fi


  files=`ulimit -n`
  if [ $os_aix -eq 1 ]; then
    if [ ! "$files" = "unlimited"  ]; then
      if [ $files -lt 8192 ]; then
        echo ""
        echo "Warning: increase open files ulimit for $ID user, it is actually too low ($files)"
        echo "  under root: chuser  nofiles=8192 $ID"
      fi
    fi
  else # Linux
    if [ ! "$files" = "unlimited"  ]; then
      if [ $files -lt 8192 ]; then
        echo ""
        echo "Warning: increase open files ulimit for $ID user, it is actually too low ($files)"
        echo "  under root: vi /etc/security/limits.conf"
        echo "    @$ID        hard    nofile            8192"
        echo "    @$ID        soft    nofile            8192"
      fi
    fi
  fi
fi # collector

# Check process limits on AIX only
if [ $os_aix -eq 1 ]; then
  maxuproc=`lsattr -El sys0 -a maxuproc| awk '{print $2}'`
  if [ ! "$maxuproc"x = "x" ]; then
    if [ $maxuproc -lt 129 ]; then
      echo ""
      echo "Warning: definitely increase user process limit, it is actually too low ($maxuproc)"
      echo "  under root: chdev -l sys0 -a maxuproc=1024"
    else
      if [ $maxuproc -lt 1024 ]; then
        echo ""
        echo "Warning: increase user process limit, it could be low when you monitoring a lot of devices ($maxuproc)"
        echo "  under root: chdev -l sys0 -a maxuproc=1024"
      fi
    fi
  fi
fi


#
# update etc/storage-list.cfg by new storage templates
#

#SVC/Storwize
exist=`grep SWIZ $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed -e 's/:stor2rrd:/:\$wlabel:/g' -e s/stor2rrd\.cfg/\$wlabel\.cfg/g' >> $HOMELPAR/etc/storage-list.cfg

#
# IBM STORWIZE, IBM SVC and IBM FlashSystem
#
# Storage name alias:SWIZ:control enclosure IP/hostname:ssh_key_file:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
#stor_alias:SWIZ:stor_host.example.com:/home/stor2rrd/.ssh/id_stor_alias_rsa
#stor_alias-1:SWIZ:stor_host-1.example.com:/home/stor2rrd/.ssh/id_stor_alias_rsa:1024:512:5


#
# Following poarameters do not have to be used, they are only about replacing defaults
# per storage base
#
# VOLUME_AGG_DATA_LIM/VOLUME_AGG_IO_LIM: data/io limits for displaing volumes in aggregated graphs
#    global defauls are set in etc/stor2rrd.cfg: VOLUME_IO_MAX=100; VOLUME_DATA_MAX=1024
# SAMPLE_RATE_MINS: says how often is downloaded data from the storage in minutes
#                   it replaces global default from stor2rrd.cfg (STEP=300 --> 5mins)
#                   storages with thousands of LUNs/VOLUMEs might need more time to get stats

END
fi

# XIV
exist=`grep XIV $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# IBM XIV
#
# Storage name alias:XIV:storage ip/hostname:password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# Password for the user stor2rrd on the storage
#
#xiv01:XIV:xiv_host01.example.com:password
#xiv02:XIV:xiv_host02.example.com:password:1024:10:15

END
fi

# DS5K
exist=`grep DS5K $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# IBM DS3000/4000/5000 & DSC3700
# NetApp E-series (use DS5K as storage type)
# Dell PowerVault MD3000 (use DS5K as storage type)
#
#storage_alias:DS5K:storage user:user_password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
#new storages can be configured to use username/password (use "monitoring" account), old ones do not have this option
#
#DS3700:DS5K:monitor:password:1024:10
#DS5020:DS5K

END
fi

# Hitachi HUS
exist=`grep HUS $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# Hitachi HUS
#
#storage_alias:HUS:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
#
#HUS110:HUS:1024:10
#HUS130:HUS:
#AMS2000-alias:HUS:

END
fi

# HP 3PAR
exist=`grep 3PAR $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# HP 3PAR
#
# Storage name alias:3PAR:storage IP/hostname:ssh_key_file:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
#3PAR01-alias01:3PAR:3par_host.example.com:/home/stor2rrd/.ssh/id_stor_alias_rsa:1024:10
#3PAR02-alias01:3PAR:3par_host.example.com:

END
fi


# NetApp
exist=`grep -i netapp $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# NetApp
#
# NetApp Alias:NETAPP:NetApp mode [CMODE|7MODE]:hostname/IP:ssh port:API port:API uses SSL/HTTPS [0|1]:API user name:API encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#cmode-alias01:NETAPP:CMODE:cmode_host.example.com:22:80:0:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10
#7mode-alias01:NETAPP:7MODE:7mode_host.example.com:22:80:0:stor2rrd:KT4mXVI9N0BUPjZdVQo=:0:0

END
fi

# EMC VNXe

exist=`grep -i ":VNXE:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# EMC VNXe
#
# Storage Alias:VNXE:IP address or hostname:storage user:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#EMC-VNXe-alias01:VNXE:vnxe_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10
#EMC-VNXe-alias01:VNXE:vnxe_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=

END
fi


# EMC Unity

exist=`grep -i ":UNITY:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# EMC Unity
#
# Storage Alias:UNITY:IP address or hostname:storage user:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#EMC-Unity-alias01:UNITY:unity_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10
#EMC-Unity-alias01:UNITY:unity_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=

END
fi


# EMC VNX for file

exist=`grep -i ":VNX:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# EMC VNX for file (Celerra)
#
# Storage Alias:VNXF:IP address or hostname:storage user:ssh_key_file:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
#VNX-file_alias:VNXF:vnxf_host.example.com:stor2rrd:/home/stor2rrd/.ssh/id_rsa:1024:10:
#VNX-file_alias:VNXF:vnxf_host.example.com:stor2rrd

END
fi


# EMC VNX
exist=`grep -i ":VNX:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# EMC VNX block
#
# Storage Alias:VNX:SPA IP address/hostname:SPB IP address/hostname:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM
#EMC-VNX-block_alias:VNX:vnxb_spa_host.example.com:vnxb_spb_host.example.com:1024:10:
#EMC-VNX-block_alias:VNX:vnxb_spa_host.example.com:vnxb_spb_host.example.com

END
fi


# Hitachi VSP-G and HUS-VM
exist=`grep -i vspg $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# Hitachi VSP-G
# HPE XP7 (use VSPG as storage type)
#
# Storage Alias : VSPG : IP address : user : password : /etc/horcm.conf : VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
# Use storage SVC IP here (CCI uses storage node IP)
#VSPG-600-alias01:VSPG:vspg_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=:/etc/horcm1.conf:1024:10:
#VSPG-400-alias01:VSPG:vspg_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=:/etc/horcm2.conf

END
fi

# DotHill
exist=`grep -i ":DOTHILL:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# DotHill AssuredSAN and its rebrands like Lenovo S2200 or HPE MSA2000/P2000, Quantum StorNext, Dell EMC PowerVault ME4
#
# Storage Alias:DOTHILL:Controller_A IP address or hostname:Controller_B IP address or hostname:[http|https]:storage user:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#DOTHILL_AssuredSAN-alias01:DOTHILL:ctla_host.example.com:ctlb_host.example.com:http:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#LENOVO_S2000-alias01:DOTHILL:ctla_host.example.com:ctlb_host.example.com:http:stor2rrd:KT4mXVI9N0BUPjZdVQo=
#HPE_MSA2000-alias01:DOTHILL:ctla_host.example.com:ctlb_host.example.com:http:stor2rrd:KT4mXVI9N0BUPjZdVQo=


END
fi

# EMC VMAX
exist=`grep -i ":VMAX:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# EMC VMAX
#
# Storage Alias:VMAX:Symmetrix id:Unisphere IP or hostname:Unisphere port:storage user:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#EMC-VMAX-alias01:VMAX:000295701111:vmax_host.example.com:8443:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#EMC-VMAX-alias01:VMAX:000295701111:vmax_host.example.com:8443:stor2rrd:KT4mXVI9N0BUPjZdVQo=



END
fi

# Compellent
exist=`grep -i ":COMPELLENT:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# Dell SC Series (Compellent)
#
# Storage name from Enterprise Manager:COMPELLENT:IP or hostname of the Enterprise Manager:port:storage user:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#Dell-Compellent01:COMPELLENT:ent-manager_host.example.com:3033:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#Dell-Compellent01:COMPELLENT:ent-manager_host.example.com:3033:stor2rrd:KT4mXVI9N0BUPjZdVQo=


END
fi

# Huawei OceanStor
exist=`grep -i ":OCEANSTOR:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
#
# Huawei OceanStor, Dorado
#
# Use :OCEANSTOR: even in case of Dorado configuration
# Storage Alias:OCEANSTOR:Controller_A IP address or hostname:Controller_B IP address or hostname:storage user:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#huawei-alias01:OCEANSTOR:ctla_host.example.com:ctlb_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#huawei-alias01:OCEANSTOR:ctla_host.example.com:ctlb_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=


END
fi

# Pure Storage
exist=`grep -i ":PURE:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# Pure Storage FlashArray
#
# Storage Alias:PURE:IP or hostname:storage user:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#purestorage-alias01:PURE:pure_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#purestorage-alias01:PURE:pure_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=


END
fi

# Pure Storage FlashBlade
exist=`grep -i ":PUREBLADE:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# Pure Storage FlashBlade
#
# Storage Alias:PUREBLADE:IP or hostname:API token:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
#purestorageblade-alias01:PUREBLADE:pureblade_host.example.com:T-e7e551be-fe5d-4669-baf5-670cd8ea0560:1024:10:
#purestorageblade-alias01:PUREBLADE:pureblade_host.example.com:T-e7e551be-fe5d-4669-baf5-670cd8ea0560


END
fi

# Infinibox
exist=`grep -i ":INFINIBOX:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# INFINIDAT Infinibox
#
# Storage Alias:INFINIBOX:IP or hostname:storage user:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#Infinibox_alias01:INFINIBOX:infinibox_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#Infinibox_alias01:INFINIBOX:infinibox_host.example.com:stor2rrd:KT4mXVI9N0BUPjZdVQo=

END
fi

# Nimble
exist=`grep -i ":NIMBLE:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# HPE Nimble
#
# Storage Alias:NIMBLE:Array name:Storage IP or hostname:Storage ssh port:Storage user:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
#nimble_alias01:NIMBLE:nimble01:nimble_host.example.com:22:stor2rrd:1024:10:
#nimble_alias01:NIMBLE:nimble01:nimble_host.example.com:22:stor2rrd

END
fi



# EMC VPLEX
exist=`grep -i ":VPLEX:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# EMC VPLEX
#
# Storage Alias:VPLEX:Cluster name:Mgmt server IP or hostname:Mgmt server ssh port:Mgmt server user:use API [1|0] ([yes|no]):Unisphere/API IP or hostname:API port:API user name:API encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#EMC-VPLEX_alias01:VPLEX:VPLEX-cluster-name:vplex_mgmt.example.com:22:stor2rrd:1:vplex_api.example.com:443:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
# If you do not use VPLEX API access then you do not need to fill in API fields, leave them empty as it this example
#EMC-VPLEX_alias01:VPLEX:VPLEX-cluster-name:vplex_mgmt.example.com:22:stor2rrd:0:::::


END
fi

# EMC DataDomain
exist=`grep -i ":DATADOMAIN:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# EMC DataDomain
#
# Storage Alias:VNXE:IP address or hostname:user:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
#EMC-DataDomain01:DATADOMAIN:dd_host.example.com:stor2rrd:1024:10:
#EMC-DataDomain01:DATADOMAIN:dd_host.example.com:stor2rrd


END
fi

# Fujitsu ETERNUS
exist=`grep -i ":ETERNUS:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# Fujitsu ETERNUS
#
# Storage Alias:ETERNUS:Controller_A IP address or hostname:Controller_B IP address or hostname:storage user:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
#eternus-alias01:ETERNUS:ctla_host.example.com:ctlb_host.example.com:stor2rrd:1024:10:
#eternus-alias01:ETERNUS:ctla_host.example.com:ctlb_host.example.com:stor2rrd

END
fi

# EMC Isilon
exist=`grep -i ":ISILON:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# Dell EMC Isilon
#
# Storage Alias:ISILON:IP address or hostname:storage user:REST API port:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#isilon-alias01:ISILON:isilon_host.example.com:8080:stor2rrd:KT4mXVI9N0BUPjZdVQo:1024:10:
#isilon-alias01:ISILON:isilon_host.example.com:8080:stor2rrd:KT4mXVI9N0BUPjZdVQo

END
fi

# DataCore
exist=`grep -i ":DATACORE:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# DataCore Storage
#
# Storage Alias:DATACORE:Node IP/hostname:Proxy REST API IP/hostname (leave blank if not used):[http|https]:storage user:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#datacore-alias01:DATACORE:datacore_node.example.com:datacore_proxy_rest-api.example.com:http:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#datacore-alias01:DATACORE:datacore_node.example.com::http:stor2rrd:KT4mXVI9N0BUPjZdVQo=

END
fi


# XtremIO
exist=`grep -i ":XTREMIO:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# Dell EMC XtremIO
#
# Storage Alias:XTREMIO:Cluster name:XMS IP or hostname:XMS GUI/API port:XMS user:encrypted XMS user password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#xtremio-alias01:XTREMIO:XIO-01:XMS_host.example.com:443:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#xtremio-alias01:XTREMIO:XIO-01:XMS_host.example.com:443:stor2rrd:KT4mXVI9N0BUPjZdVQo=

END
fi


# HPE StoreOnce
exist=`grep -i ":STOREONCE:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# HPE StoreOnce
#
# Storage Alias:STOREONCE:Node IP/hostname:storage user:[http|https]:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#storeonce-alias01:STOREONCE:storeonce_node.example.com:http:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#storeonce-alias01:STOREONCE:storeonce_node.example.com:http:stor2rrd:KT4mXVI9N0BUPjZdVQo=

END
fi


# HPE StoreVirtual
exist=`grep -i ":STOREVIRTUAL:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# HPE StoreVirtual, LeftHand
#
# Storage Alias:STOREVIRTUAL:Cluster IP/hostname:storage user:port:encrypted password:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
# to encrypt password use: perl ./bin/spasswd.pl
#storevirtual-alias01:STOREVIRTUAL:storevirtual_cluster.example.com:16022:stor2rrd:KT4mXVI9N0BUPjZdVQo=:1024:10:
#storevirtual-alias01:STOREVIRTUAL:storevirtual_cluster.example.com:16022:stor2rrd:KT4mXVI9N0BUPjZdVQo=

END
fi

# Ceph
#exist=`grep -i ":CEPH:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
#if [ $exist -eq 0 ]; then
#  # add storages type in storage-list.cfg
#  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg
#
##
## Ceph
##
## Storage Alias:CEPH:Storage IP address or hostname:PORT:VOLUME_AGG_DATA_LIM:VOLUME_AGG_IO_LIM:SAMPLE_RATE_MINS
##Ceph-alias01:CEPH:ceph01.example.com:5000:1024:10:
##Ceph-alias01:CEPH:ceph01.example.com:5000
#
#END
#fi



# Hitachi HNAS
exist=`grep -i ":HNAS:" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in storage-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/storage-list.cfg

#
# Hitachi HNAS
#
#Storage Alias:HNAS:IP address/hostname:SNMP_VERSION:SNMP_PORT:SNMP3_USER:SNMP_COMMUNITY:SNMP_PRIV_PASS:SNMP_AUTH_PASS:SNMP_SEC_LEVEL:SNMP_AUTH_PROTOCOL:SNMP_PRIV_PROTOCOL
# SNMP v3 example
#HNAS-alias01:HNAS:hnas01.example.com:3:161:stor2rrd:public:KT4mXVI9N0BUPjZdVQo=:KT4mXVI9N0BUPjZdVQo=:authNoPriv:SHA:AES
# SNMP v2c example
#HNAS-alias02:HNAS:hnas01.example.com:2c:161::public:::::

END
fi

# Brocade Network Advisor
exist=`grep -i ":BNA:" $HOMELPAR/etc/san-list.cfg|wc -l|sed 's/ //g'`
if [ $exist -eq 0 ]; then
  # add storages type in san-list.cfg
  cat << END | eval 'sed 's/:stor2rrd:/:\$wlabel:/g'' >> $HOMELPAR/etc/san-list.cfg


#
# Brocade Network Advisor (BNA)
# <BNA IP or hostname>:<port>:BNA:<API user>:<encrypted password>:<backup BNA node IP or hostname>
# to encrypt password use: perl ./bin/spasswd.pl
# 192.168.1.1:443:BNA:stor2rrd:KT4mXVI9N0BUPjZdVQo=:192.168.1.2

END
fi



#
# END of update etc/storage-list.cfg by new storage templates
#


cd $HOMELPAR
if [  $COLLECTOR -eq 0 ]; then
  if [ $os_aix -eq 0 ]; then
    free=`df .|grep -iv filesystem|xargs|$AWK '{print $4}'`
    freemb=`echo "$free/1048"|bc 2>/dev/null`
    if [ $? -eq 0 -a ! "$freemb"x = "x" ]; then
      if [ $freemb -lt 2048 ]; then
        echo ""
        echo "WARNING: free space in $HOMELPAR is too low : $freemb MB"
        echo "         note that 1 storage needs 1 - 2 GB space depends on number of volumes/pools/ranks/disks/mdisks"
      fi
    fi
  else
    free=`df .|grep -iv filesystem|xargs|$AWK '{print $3}'`
    freemb=`echo "$free/2048"|bc 2>/dev/null`
    if [ $? -eq 0 -a ! "$freemb"x = "x" ]; then
      if [ $freemb -lt 2048 ]; then
        echo ""
        echo "WARNING: free space in $HOMELPAR is too low : $freemb MB"
        echo "         note that 1 storage needs 1 - 2 GB space depends on number of volumes/pools/ranks/disks/mdisks"
      fi
    fi
  fi
fi

if [ $VER_ORG -lt 43 ]; then
  # for SVC/Storwize and stor2rrd less than 0.43 has been wrongly filled up tiered pool capacity data
  # so remove them ...
  cd $HOMELPAR/data
  for storage in */MDISK
  do
    if [ ! "$DEMO"x = "x" ]; then
       if [ $DEMO -eq 1 ]; then
         break # skip on demo
       fi
    fi
    if [ -L "$storage" ]; then
      storage_name=`dirname $storage`
      tar cf $HOMELPAR/tmp/$storage_name-pool-cap.tar $storage_name/POOL/*-cap.rrd
      echo ""
      echo "Removing wrong tiering pool capacity data: rm -f $storage_name/POOL/*-cap.rrd"
      echo "Backup is here: tmp/$storage_name-pool-cap.tar"
      rm -f $storage_name/POOL/*-cap.rrd
    fi
  done
fi

# setting up the font dir (necessary for 1.3 on AIX)
FN_PATH="<?xml version=\"1.0\"?>
<!DOCTYPE fontconfig SYSTEM \"fonts.dtd\">
<fontconfig>
<dir>/opt/freeware/share/fonts/dejavu</dir>
</fontconfig>"

if [ ! -f "$HOME/.config/fontconfig/.fonts.conf" -o `grep -i deja "$HOME/.config/fontconfig/.fonts.conf" 2>/dev/null|wc -l` -eq 0 ]; then
  if [ ! -d "$HOME/.config" ]; then
    mkdir "$HOME/.config"
  fi
  if [ ! -d "$HOME/.config/fontconfig" ]; then
    mkdir "$HOME/.config/fontconfig"
  fi
  echo $FN_PATH >> "$HOME/.config/fontconfig/.fonts.conf"
fi
chmod 644 "$HOME/.config/fontconfig/.fonts.conf"
# no, no, it issues this error:
# Fontconfig warning: "/opt/freeware/etc/fonts/conf.d/50-user.conf", line 9: reading configurations from ~/.fonts.conf is deprecated.
#if [ ! -f "$HOME/.fonts.conf" ]; then
#  echo $FN_PATH > "$HOME/.fonts.conf"
#  chmod 644 "$HOME/.fonts.conf"
#fi

# for web server user home
if [ ! -d "$HOMELPAR/tmp/home" ]; then
  mkdir "$HOMELPAR/tmp/home"
fi
#if [ ! -f "$HOMELPAR/tmp/home/.fonts.conf" ]; then
#  echo $FN_PATH > "$HOMELPAR/tmp/home/.fonts.conf"
#fi
if [ ! -d "$HOMELPAR/tmp/home/.config" ]; then
  mkdir "$HOMELPAR/tmp/home/.config" 2>/dev/null
  if [ ! $? -eq 0 ]; then
    # Once we saw tmp/home dir created and under apache user what is wrong, it is a workaround
    mv "$HOMELPAR/tmp/home" "$HOMELPAR/tmp/home.$$"
    mkdir "$HOMELPAR/tmp/home/"
    mkdir "$HOMELPAR/tmp/home/.config"
  fi
fi
if [ ! -d "$HOMELPAR/tmp/home/.config/fontconfig" ]; then
  mkdir "$HOMELPAR/tmp/home/.config/fontconfig"
fi
if [ ! -f "$HOMELPAR/tmp/home/.config/fontconfig/fonts.conf" ]; then
  echo $FN_PATH >> "$HOMELPAR/tmp/home/.config/fontconfig/fonts.conf"
fi
chmod 755 "$HOMELPAR/tmp/home"
chmod 755 "$HOMELPAR/tmp/home/.config"
chmod 755 "$HOMELPAR/tmp/home/.config/fontconfig"
chmod 644 "$HOMELPAR/tmp/home/.config/fontconfig/fonts.conf"

# cleaning old *cmd files not used sinc 1.0
rm -f $HOMELPAR/tmp/*.cmd
rm -f $HOMELPAR/tmp/*.out

rrdtool=$RRD_act

if [ $VER_ORG -lt 111 ]; then
  # set minimal_heartbeat to 1380sec (23minutes) same as is default for 1.00 version
  echo ""
  echo "Setting new RRDTool minimal_heartbeat, it might take a minute"
  for storage in $HOMELPAR/data/*
  do
    if [ ! -d "$storage" ]; then
      continue
    fi
    storage_base=`basename $storage`
    echo "Working for storage: $storage_base ..."
    stor_hb=1380
    if [ -f "$HOMELPAR/data/$storage_base/XIV" ]; then
      stor_hb=1980 # higher heartbeat for XIV
    fi
    for rrd in $storage/*/*rr*
    do
      for item in `$rrdtool info $rrd|grep minimal_heartbeat| grep -v $stor_hb| sed -e 's/^.*\[//' -e 's/\].*$//'`
      do
        $rrdtool tune $rrd --heartbeat $item:$stor_hb
      done
    done
  done
fi

if [ $VER_ORG -lt 211 ]; then
  # set minimal_heartbeat to 900 for switches, some older version set that to 420, not sure which one
  echo ""
  echo "Setting new RRDTool minimal_heartbeat for SAN switches, it might take a minute"
  for storage in $HOMELPAR/data/*
  do
    if [ ! -d "$storage" ]; then
      continue
    fi
    storage_base=`basename $storage`
    if [ ! -f "$HOMELPAR/data/$storage_base/PORTS.cfg" ]; then
      continue # it is not a SAN switch
    fi
    #echo "Working for switch: $storage_base ..."
    for rrd in $storage/port*.rrd
    do
      for item in `$rrdtool info $rrd|grep minimal_heartbeat| grep -v 900| sed -e 's/^.*\[//' -e 's/\].*$//'`
      do
        $rrdtool tune $rrd --heartbeat $item:900
      done
    done
  done
fi

# v2.54: add exclude text into cfg files
if [ $VER_ORG -lt 254 ]; then
  exist=`grep -i "THIS CFG FILE IS NO LONGER USED" $HOMELPAR/etc/storage-list.cfg|wc -l|sed 's/ //g'`
  if [ $exist -eq 0 ]; then
    cat << END > $HOMELPAR/etc/storage-list.cfg-tmp
##########################################################################
#                                                                        #
#           !!!!!! THIS CFG FILE IS NO LONGER USED !!!!!!                #
#                                                                        #
# USE UI FOR STORAGE MANAGEMENT                                          #
# Upgrade to v2.60 converts all storages to the new format automatically #
#                                                                        #
# UI --> setting icon on the top right --> Storages                      #
#                                                                        #
##########################################################################


END
    cat $HOMELPAR/etc/storage-list.cfg >> $HOMELPAR/etc/storage-list.cfg-tmp
    mv $HOMELPAR/etc/storage-list.cfg-tmp $HOMELPAR/etc/storage-list.cfg
  fi

  exist=`grep -i "THIS CFG FILE IS NO LONGER USED" $HOMELPAR/etc/san-list.cfg|wc -l|sed 's/ //g'`
  if [ $exist -eq 0 ]; then
    cat << END > $HOMELPAR/etc/san-list.cfg-tmp
#########################################################################
#                                                                       #
#           !!!!!! THIS CFG FILE IS NO LONGER USED !!!!!!               #
#                                                                       #
# USE UI FOR STORAGE MANAGEMENT                                         #
# Upgrade to v2.60 converts all devices to the new format automatically #
#                                                                       #
# UI --> setting icon on the top right --> SAN                          #
#                                                                       #
#########################################################################


END
    cat $HOMELPAR/etc/san-list.cfg >> $HOMELPAR/etc/san-list.cfg-tmp
    mv $HOMELPAR/etc/san-list.cfg-tmp $HOMELPAR/etc/san-list.cfg
  fi

  exist=`grep -i "THIS CFG FILE IS NO LONGER USED" $HOMELPAR/etc/lan-list.cfg|wc -l|sed 's/ //g'`
  if [ $exist -eq 0 ]; then
    cat << END > $HOMELPAR/etc/lan-list.cfg-tmp
#########################################################################
#                                                                       #
#           !!!!!! THIS CFG FILE IS NO LONGER USED !!!!!!               #
#                                                                       #
# USE UI FOR STORAGE MANAGEMENT                                         #
# Upgrade to v2.60 converts all devices to the new format automatically #
#                                                                       #
# UI --> setting icon on the top right --> LAN                          #
#                                                                       #
#########################################################################


END
    cat $HOMELPAR/etc/lan-list.cfg >> $HOMELPAR/etc/lan-list.cfg-tmp
    mv $HOMELPAR/etc/lan-list.cfg-tmp $HOMELPAR/etc/lan-list.cfg
  fi

  exist=`grep -i "THIS CFG FILE IS NO LONGER USED" $HOMELPAR/etc/storage-groups.cfg|wc -l|sed 's/ //g'`
  if [ $exist -eq 0 ]; then
    cat << END > $HOMELPAR/etc/storage-groups.cfg-tmp
#########################################################################
#                                                                       #
#           !!!!!! THIS CFG FILE IS NO LONGER USED !!!!!!               #
#                                                                       #
# USE UI FOR STORAGE MANAGEMENT                                         #
# Upgrade to v2.60 converts all devices to the new format automatically #
#                                                                       #
# UI --> setting icon on the top right --> Storage Grouping             #
#                                                                       #
#########################################################################


END
    cat $HOMELPAR/etc/storage-groups.cfg >> $HOMELPAR/etc/storage-groups.cfg-tmp
    mv $HOMELPAR/etc/storage-groups.cfg-tmp $HOMELPAR/etc/storage-groups.cfg.cfg
  fi

fi

if [ $VER_ORG -lt 262 ]; then
  # rename rrdtool field for OceanStor only:
  for storage in $HOMELPAR/data/*
  do
    if [ ! -d "$storage" ]; then
      continue
    fi
    storage_base=`basename "$storage"`
    if [ ! -f "$HOMELPAR/data/$storage_base/OCEANSTOR" ]; then
      continue
    fi
    echo "$storage_base: deduplication rate enhancement"
    for rrd in $storage/POOL/*-comp.rrc
    do
      if [ ! -f "$rrd" ]; then
        continue
      fi
      check_item=`$rrdtool fetch $rrd AVERAGE | grep reserve1 | wc -l`
      if [ $check_item -eq 0 ]; then
        continue
      fi
      $rrdtool tune $rrd -r reserve1:data_reduce_ratio
    done
  done
fi

if [ $VER_ORG -lt 732 ]; then
  # rename rrdtool field for Infiniguard only:
  for storage in $HOMELPAR/data/*
  do
    if [ ! -d "$storage" ]; then
      continue
    fi
    storage_base=`basename "$storage"`
    if [ ! -f "$HOMELPAR/data/$storage_base/INFINIGUARD" ]; then
      continue
    fi
    echo "$storage_base: snapshot capacity enhancement"
    for rrd in $storage/DDE/*-cap.rrc
    do
      if [ ! -f "$rrd" ]; then
        continue
      fi
      check_item=`$rrdtool fetch $rrd AVERAGE | grep reserve1 | wc -l`
      if [ $check_item -eq 0 ]; then
        continue
      fi
      $rrdtool tune $rrd -r reserve1:snapshot_used
      check_item=`$rrdtool fetch $rrd AVERAGE | grep reserve2 | wc -l`
      if [ $check_item -eq 0 ]; then
        continue
      fi
      $rrdtool tune $rrd -r reserve2:snapshot_free
      check_item=`$rrdtool fetch $rrd AVERAGE | grep reserve3 | wc -l`
      if [ $check_item -eq 0 ]; then
        continue
      fi
      $rrdtool tune $rrd -r reserve3:snapshot_count
    done
  done
fi

if [ $VER_ORG -lt 741 ]; then
  # rename rrdtool field for VTRAK only:
  for storage in $HOMELPAR/data/*
  do
    if [ ! -d "$storage" ]; then
      continue
    fi
    storage_base=`basename "$storage"`
    if [ ! -f "$HOMELPAR/data/$storage_base/VTRAK" ]; then
      continue
    fi
    echo "$storage_base: error metrics enhancement"
    for rrd in $storage/DRIVE/*rrd
    do
      if [ ! -f "$rrd" ]; then
        continue
      fi
      check_item=`$rrdtool fetch $rrd AVERAGE | grep reserve1 | wc -l`
      if [ $check_item -eq 0 ]; then
        continue
      fi
      $rrdtool tune $rrd -r reserve1:non_rw_error
    done
  done
fi




# RRDTool version checking for graph zooming
$RRD_act|grep graphv >/dev/null 2>&1
if [ $? -eq 1 -a  $COLLECTOR -eq 0 ]; then
  # suggest RRDTool upgrade
  echo ""
  rrd_version=`$rrd -v|head -1|$AWK '{print $2}'`
  echo "Consider RRDtool upgrade to version 1.3.5+ (actual one is $rrd_version)"
  if [ "$WLABEL" = "STOR2RRD" ]; then
    echo "This will allow graph zooming: http://www.stor2rrd.com/zoom.html"
  fi
  echo ""
fi

# force to load DS8k configuration during next run
rm -f $HOMELPAR/tmp/*conf.tmp

# same for SVC
rm -f $HOMELPAR/data/*/*svcconf_*data
rm -f $HOMELPAR/data/*/svc.config.backup.xml

# forces to run config for DS5K, use only for DS5K!!
for storage in $HOMELPAR/data/*
do
  if  [ -f "$storage/DS5K" ]; then
    rm -f "$storage/config.html"
  fi
done


if [ $VER_ORG -lt 106 ]; then
  # clean out DS8k POOL cmd files (due to new pool front-end data)
  rm -f $HOMELPAR/tmp/*/POOL-*.cmd
fi


if [ $VER_ORG -lt 112 ]; then
  # clean out /var/tmp where 1.09 created 0 sized files without removing them
  echo "Cleaning up ..."
  find /var/tmp -name  "*-*-*-[d,w,m,y]-web-[0-9]*.cmd" -exec rm -f {} \; 2>/dev/null
fi


if [ $VER_ORG -lt 130 ]; then
  # clean out SVC "real" command files
  find $HOMELPAR/tmp -name "*POOL-*real*.cmd" -exec rm -f {} \;
fi
if [ $VER_ORG -lt 128 ]; then
  # clean out NetApp NODE data (new structure since 1.28)
  rm -f $HOMELPAR/data/*/NODE/*
fi
if [ $VER_ORG -lt 137 ]; then
  rm -f $HOMELPAR/tmp/*/*_cache_usage*
fi


if [ $os_linux -gt 0 -a  $COLLECTOR -eq 0 ]; then
  # LinuxSE warning
  SELINUX=`ps -ef | grep -i selinux| grep -v grep|wc -l`

  if [ "$SELINUX" -gt 0  ]; then
    GETENFORCE=`getenforce 2>/dev/null`
    if [ "$GETENFORCE" = "Enforcing" ]; then
      echo ""
      echo "Warning!!!!!"
      echo "SELINUX status is Enforcing, it might cause problem during Apache setup"
      echo "like this in Apache error_log: (13)Permission denied: access to /XXXX denied"
      echo ""
    fi
  fi
fi

# Remove command files, those should not be used for HUS and 3PAR (only DS5K related stuff)
# fixed in 1.25-7
rm -f $HOMELPAR/tmp/*/POOL*sum_data_total*
rm -f $HOMELPAR/tmp/*/POOL*sum_io_total*

# Refresh custom restriction after the upgrade
#rm -f $HOMELPAR/tmp/.custom-group/*.cmd
# remove custom cmd definitions to be sure that they are reinitiated after upgrade,
rm -f $HOMELPAR/tmp/custom-group/* 2>/dev/null

# refresh storage configuration files
rm -f $HOMELPAR/tmp/config-*.touch 2>/dev/null
rm -f $HOMELPAR/tmp/*conf_time 2>/dev/null
rm -f $HOMELPAR/tmp/*-check-vsan 2>/dev/null

# remove old JSON, very old one might cause a problem, actually it is distributed in lib
rm -f $HOMELPAR/bin/JSON*pm

# fix a bug from 0.21  --> remove volumes.cfg (volumes colour table)
# even in 1.27 was a bug with volumes.col and cust group *.col for VSP-G storages
# clean it up anyway every time
find $HOMELPAR/data -name \*\.col -exec rm -f {} \; 2>/dev/null
rm -f $HOMELPAR/tmp/custom-group/*.col 2>/dev/null

# delete of old not being refreshed command files, old custom groups, storages etc
find $HOMELPAR/tmp -name \*\.cmd -mtime +2 -exec rm -f {} \; 2>/dev/null

# do that before ./bin/check_rrdtool.sh to can interrupt it
if [ ! "$version_new"x = "x" ]; then
  date=`date "+%Y-%m-%d_%H:%M"`
  echo "$version_new $date" >> $HOMELPAR/etc/version.txt
fi
echo "$HOMELPAR" > $HOME/.${wlabel}_home 2>/dev/null

if [ -f "$HOMELPAR/bin/load_sanperf.sh" ]; then
  # bin/load_sanperf.sh apeard since some version in bin dir what is wrong and it confuses people
  rm -f "$HOMELPAR/bin/load_sanperf.sh"
fi

# PPRC cleaning cmd file, since 2.00 they will not created if no pprc in place
rm -f $HOMELPAR/tmp/*/PORT-pprc*cmd

# Apache authorization
if [ "$WLABEL" = "CIRO" ]; then
  cat << END > $HOMELPAR/html/.htaccess
SetEnv XORUX_ACCESS_CONTROL 1
AuthUserFile $HOMELPAR/etc/web_config/htusers.cfg
AuthName "Authorized personnel only."
AuthType Basic
Require valid-user
<Files "index.html">
  Header append Set-Cookie "cgi-path=/ciro-cgi"
</Files>
END
  
  if [ -f $HOMELPAR/www/.htaccess ]; then
    if [ `grep "ciro-cgi" $HOMELPAR/www/.htaccess 2>/dev/null| wc -l| sed 's/ //g'` -eq 0 ]; then
      cp $HOMELPAR/html/.htaccess $HOMELPAR/www/.htaccess
    fi
  fi
else
  cat << END > $HOMELPAR/html/.htaccess
SetEnv XORUX_ACCESS_CONTROL 1
AuthUserFile $HOMELPAR/etc/web_config/htusers.cfg
AuthName "Authorized personnel only."
AuthType Basic
Require valid-user
END
fi

# WEB GUI cleaning
rm -f $HOMELPAR/tmp/menu.cache $HOMELPAR/tmp/env.cache
rm -f $HOMELPAR/html/app.manifest $HOMELPAR/www/app.manifest $WEBDIR/app.manifest

if [ "$VM_IMAGE"x = "x" -a "$VI_IMAGE"x = "x" ]; then
  # this is intended only for image env, making changes for ACL in httpd.conf
  rm -f $HOMELPAR/bin/acl_enable.sh
fi

# Fix for wrong script line in crontab on the virtual appliance 2.05
# load_oceanstor.sh --> load_oceanstorperf.sh
if [ ! "$VM_IMAGE"x = "x" ]; then
  if [ $VM_IMAGE -eq 1 ]; then
    crontab_tmp="/tmp/crontab.$$"
    crontab -l > $crontab_tmp

    # OceanStor - wrong entry in 2.05 appliance crontab
    grep load_oceanstor.sh $crontab_tmp >/dev/null 2>&1
    if [ $? -eq 0 ]; then
      grep load_oceanstorperf.sh $crontab_tmp >/dev/null 2>&1
      if [ $? -eq 0 ]; then
        sed --in-place=.old '/load_oceanstor\.sh/d' $crontab_tmp
      else
        sed --in-place=.old 's/load_oceanstor\./load_oceanstorperf\./g' $crontab_tmp
      fi
      if [ -s $crontab_tmp ]; then
        crontab < $crontab_tmp
      else
        echo "ERROR: crontab has not been updated, perhaps not enough space in /tmp, OceanStor has a wrong entry in crontab"
        echo ""
      fi
      crontab -l > $crontab_tmp
    fi

    grep  "load_ds8perf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# IBM DS8000 storage agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_ds8perf.sh > /home/$wlabel/$wlabel/load_ds8perf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_svcperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# IBM SVC/Storwize/Flash storage agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_svcperf.sh > /home/$wlabel/$wlabel/load_svcperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_ds5perf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# DS500/DS4000/DS3000/DCS3700 & NetApp E-series storage agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_ds5perf.sh > /home/$wlabel/$wlabel/load_ds5perf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_xivperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# IBM XIV storage agent" >> $crontab_tmp
      echo "0,10,20,30,40,50 * * * * /home/$wlabel/$wlabel/load_xivperf.sh > /home/$wlabel/$wlabel/load_xivperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_husperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Hitachi HUS and AMS 2000 storage agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_husperf.sh > /home/$wlabel/$wlabel/load_husperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_3parperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# HPE 3PAR storage agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_3parperf.sh > /home/$wlabel/$wlabel/load_3parperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_netappperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# NetApp storage agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_netappperf.sh > /home/$wlabel/$wlabel/load_netappperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_vspgperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Hitachi VSP-G  & HPE XP7 storage agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_vspgperf.sh > /home/$wlabel/$wlabel/load_vspgperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_vmaxperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# EMC VMAX" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_vmaxperf.sh > /home/$wlabel/$wlabel/load_vmaxperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_vnxperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# EMC VNX block" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_vnxperf.sh > /home/$wlabel/$wlabel/load_vnxperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_vnxfperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# EMC VNX file" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_vnxfperf.sh > /home/$wlabel/$wlabel/load_vnxfperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_vnxeperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# EMC VNXe" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_vnxeperf.sh > /home/$wlabel/$wlabel/load_vnxeperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_unityperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# EMC Unity" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_unityperf.sh > /home/$wlabel/$wlabel/load_unityperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_dothillperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Dot Hill AssuredSAN and its rebrands like Lenovo S2200 or HPE MSA2000/P2000, Dell EMC PowerVault ME4" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_dothillperf.sh > /home/$wlabel/$wlabel/load_dothillperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_compellentperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Dell SC series (Compellent)" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_compellentperf.sh > /home/$wlabel/$wlabel/load_compellentperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_oceanstorperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Huawei OceanStor" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_oceanstorperf.sh > /home/$wlabel/$wlabel/load_oceanstorperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_vplexperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# EMC VPLEX" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_vplexperf.sh > /home/$wlabel/$wlabel/load_vplexperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_infiniboxperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Infinibox agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_infiniboxperf.sh > /home/$wlabel/$wlabel/load_infiniboxperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_nimbleperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Nimble storage agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_nimbleperf.sh  > /home/$wlabel/$wlabel/load_nimbleperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_datadomainperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# EMC DataDomain" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_datadomainperf.sh > /home/$wlabel/$wlabel/load_datadomainperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_eternusperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Fujitsu ETERNUS" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_eternusperf.sh > /home/$wlabel/$wlabel/load_eternusperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_isilonperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Dell EMC Isilon" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_isilonperf.sh > /home/$wlabel/$wlabel/load_isilonperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_pureperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# PureStorage FlashArray" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_pureperf.sh > /home/$wlabel/$wlabel/load_pureperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_purebladeperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# PureStorage FlashBlade" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_purebladeperf.sh > /home/$wlabel/$wlabel/load_purebladeperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_datacoreperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# DataCore" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_datacoreperf.sh > /home/$wlabel/$wlabel/load_datacoreperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_xtremioperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Dell EMC XtremIO" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_xtremioperf.sh > /home/$wlabel/$wlabel/load_xtremioperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_storeonceperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# HPE StoreOnce" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_storeonceperf.sh > /home/$wlabel/$wlabel/load_storeonceperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_storevirtualperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# HPE StoreVirtual, LeftHand " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_storevirtualperf.sh > /home/$wlabel/$wlabel/load_storevirtualperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_cephperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Ceph " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_cephperf.sh > /home/$wlabel/$wlabel/load_cephperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_sanperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# SAN (Brocade + Cisco + QLogic)" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_sanperf.sh >/home/$wlabel/$wlabel/logs/load_sanperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_bnaperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# BNA agent" >> $crontab_tmp
      echo "0,10,20,30,40,50 * * * * /home/$wlabel/$wlabel/load_bnaperf.sh >/home/$wlabel/$wlabel/logs/load_bnaperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_lanperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# LAN" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_lanperf.sh >/home/$wlabel/$wlabel/logs/load_lanperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_hnasperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Hitachi HNAS " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_hnasperf.sh > /home/$wlabel/$wlabel/load_hnasperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_oraclezfsperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Oracle ZFS " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_oraclezfsperf.sh > /home/$wlabel/$wlabel/load_oraclezfsperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_freenasperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# FreeNAS " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_freenasperf.sh > /home/$wlabel/$wlabel/load_freenasperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_ecsperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# EMC ECS " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_ecsperf.sh > /home/$wlabel/$wlabel/load_ecsperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_solidfireperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# NetApp SolidFire " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_solidfireperf.sh > /home/$wlabel/$wlabel/load_solidfireperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_falconstorperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# FalconStor " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_falconstorperf.sh > /home/$wlabel/$wlabel/load_falconstorperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_qnapperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# QNAP " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_qnapperf.sh > /home/$wlabel/$wlabel/load_qnapperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_synologyperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Synology " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_synologyperf.sh > /home/$wlabel/$wlabel/load_synologyperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_hcpperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Hitachi HCP " >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_hcpperf.sh > /home/$wlabel/$wlabel/load_hcpperf.out 2>&1" >> $crontab_tmp
    fi
    #grep  "load_raidixperf.sh" $crontab_tmp >/dev/null 2>&1
    #if [ ! $? -eq 0 ]; then
      #echo "" >> $crontab_tmp
      #echo "# RAIDIX " >> $crontab_tmp
      #echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_raidixperf.sh > /home/$wlabel/$wlabel/load_raidixperf.out 2>&1" >> $crontab_tmp
    #fi
    grep  "load_qumuloperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Qumulo" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_qumuloperf.sh > /home/$wlabel/$wlabel/load_qumuloperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_storagegridperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# NetApp StorageGRID" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_storagegridperf.sh > /home/$wlabel/$wlabel/load_storagegridperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_macrosanperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# MacroSAN" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_macrosanperf.sh > /home/$wlabel/$wlabel/load_macrosanperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_equallogicperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Dell EqualLogic" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_equallogicperf.sh > /home/$wlabel/$wlabel/load_equallogicperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_netbackupperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Veritas NetBackup" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_netbackupperf.sh > /home/$wlabel/$wlabel/load_netbackupperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_infiniguardperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Infiniguard agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_infiniguardperf.sh > /home/$wlabel/$wlabel/load_infiniguardperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_powerstoreperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# EMC PowerStore" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_powerstoreperf.sh > /home/$wlabel/$wlabel/load_powerstoreperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_gpfsperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# IBM Spectrum Scale" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_gpfsperf.sh > /home/$wlabel/$wlabel/load_gpfsperf.out 2>&1" >> $crontab_tmp
    fi
    #grep  "load_tatlinperf.sh" $crontab_tmp >/dev/null 2>&1
    #if [ ! $? -eq 0 ]; then
    #  echo "" >> $crontab_tmp
    #  echo "# YADRO TATLIN" >> $crontab_tmp
    #  echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_tatlinperf.sh > /home/$wlabel/$wlabel/load_tatlinperf.out 2>&1" >> $crontab_tmp
    #fi
    grep  "load_powerflexperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Dell EMC PowerFlex (ScaleIO)" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_powerflexperf.sh > /home/$wlabel/$wlabel/load_powerflexperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_rubrikperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Rubrik CDM" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_rubrikperf.sh > /home/$wlabel/$wlabel/load_rubrikperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_vtrakperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Promise VTrak" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_vtrakperf.sh > /home/$wlabel/$wlabel/load_vtrakperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_infortrendperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# Infortrend EonStor" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_infortrendperf.sh > /home/$wlabel/$wlabel/load_infortrendperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_ibmcossperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# IBM Cloud Object Storage  agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_ibmcossperf.sh > /home/$wlabel/$wlabel/load_ibmcossperf.out 2>&1" >> $crontab_tmp
    fi
    grep  "load_sannavperf.sh" $crontab_tmp >/dev/null 2>&1
    if [ ! $? -eq 0 ]; then
      echo "" >> $crontab_tmp
      echo "# SANnav agent" >> $crontab_tmp
      echo "0,5,10,15,20,25,30,35,40,45,50,55 * * * * /home/$wlabel/$wlabel/load_sannavperf.sh > /home/$wlabel/$wlabel/load_sannavperf.out 2>&1" >> $crontab_tmp
    fi
    if [ -s $crontab_tmp ]; then
      crontab < $crontab_tmp
    else
      echo "ERROR: crontab has not been updated, perhaps not enough space in /tmp, newly supported storages can mis entry in crontab"
      echo ""
    fi
    rm -f $crontab_tmp
  fi
fi


cron_all=`crontab -l 2>/dev/null| egrep "\/load.sh|\/load_.*sh " | grep $wlabel | egrep -v "#"|sed -e 's/ >.*//g' -e 's/^.*\* //g'| wc -l`
cron_uniq=`crontab -l 2>/dev/null| egrep "\/load.sh|\/load_.*sh " | grep $wlabel | egrep -v "#"|sed -e 's/ >.*//g' -e 's/^.*\* //g' |sort|uniq|wc -l`
if [ $cron_all -gt $cron_uniq ]; then
  echo "ERROR: You have probably duplicated rows in crontab, check it manually  via: crontab -e:"
  echo "=========="
  crontab -l 2>/dev/null| egrep "\/load.sh|\/load_.*sh " | grep $wlabel | egrep -v "#"|sed -e 's/ >.*//g' -e 's/^.*\* //g'| sort
  echo "=========="
  echo ""
fi

if [ $os_aix -eq 1 ]; then
  # AIX (at least) rrdtool 1.7 issue when prints mem profiling info to pwd/mon.out
  touch $HOMELPAR/$wlabel-cgi/mon.out
  chmod 777 $HOMELPAR/$wlabel-cgi/mon.out
  touch $HOMELPAR/bin/mon.out
  chmod 777 $HOMELPAR/bin/mon.out
  touch $HOMELPAR/tmp/home/mon.out 2>/dev/null
  chmod 777 $HOMELPAR/tmp/home/mon.out 2>/dev/null
fi

# remove menu cache files if they exist
rm -f $HOMELPAR/tmp/env.cache $HOMELPAR/tmp/menu.cache

# it is obviously no longer used
rm -f $HOMELPAR/load.out

if [ $free_edition_new -eq 1 ]; then
  # assure that they do not exist
  rm -f $HOMELPAR/bin/premium.* $HOMELPAR/load_data.sh $HOMELPAR/bin/offsite.sh $HOMELPAR/bin/reporter-premium.pl
fi

# cleaning, some versions left there such files
rm -f $HOMELPAR/data/*/POOL/-cap.rrd  $HOMELPAR/data/*/POOL/-cap.first $HOMELPAR/bin/p
rm -f $HOMELPAR/bin/alert-save.pl $HOMELPAR/bin/bna_stor_load.sh $HOMELPAR/bin/redhatdev  $HOMELPAR/bin/vmaxperf.pl

# remove old Volume transfer size (SWIZ)
rm -f $HOMELPAR/tmp/*/VOLUME-*transfer_size-*cmd*

# remove possibility to collect logs from UI
rm -f $HOMELPAR/bin/collect_logs.pl $HOMELPAR/stor2rrd-cgi/collect_logs.sh $HOMELPAR/html/support_logs.html $HOMELPAR/stor2rrd-cgi/stor-test-healthcheck-cgi.sh

# Fix of 2.60 when was user "stor2rrd" as default for swiz, 3par and xiv during creating devicecfg.json file
# USER_... must be used instead from etc/stor2rrd.cfg
if [ "$version_org" = "2.60" ]; then
  # do not use $VER_ORG, it must be exact 2.60 here only
  if [ -f "$HOMELPAR/etc/web_config/devicecfg.json" ]; then
    echo "Checking consistency storage management"
    .  $CFG
    export HOMELPAR
    cp "$HOMELPAR/etc/web_config/devicecfg.json" "$HOMELPAR/etc/web_config/devicecfg.json-original" 2>/dev/null
    $PERL $HOMELPAR/bin/storage_management_complete.pl
    chmod 666 "$HOMELPAR/etc/web_config/devicecfg.json" 2>/dev/null
  fi
fi

if [ $os_aix -eq 1 ]; then
  # refresh font caching
  # it creates it in /home/stor2rrd/tmp/home/.cache/fontconfig and in /home/stor2rrd/.cache/fontconfig
  if [ ! -d "$HOMELPAR/tmp/home" ]; then
    mkdir "$HOMELPAR/tmp/home"
  fi
  fc-cache -fv 1>/dev/null 2>&1
  HOME="$HOMELPAR/tmp/home"; fc-cache -fv 1>/dev/null 2>&1
fi

if [ -f "$HOMELPAR/data/_DB/data.db" -a $VER_ORG -lt 705 ]; then
  echo "Removing XorMon DB, wait an hour for DB re-creation, then check XorMon UI"
  echo ""
  rm -rf "$HOMELPAR/data/_DB/data.db"
fi

# old stuff
rm -f $HOMELPAR/bin/stor-search.pl $HOMELPAR/html/top.src $HOMELPAR/stor2rrd-cgi/stor-search.sh $HOMELPAR/www/top.src $HOMELPAR/etc/.stor2rrd.cfg.swp $HOMELPAR/bin/.qs_volume.pl.swp

# IPv6 support, however not on AIX, there is an issue
if [ ! $os_aix -eq 1 ]; then
  rhel_ver_check=`rpm --eval '%{rhel}'`
  if [ $? -eq 0 ]; then
    # skip CentOS 6 and older
    if [ ! -n "$rhel_ver_check" ] || [ `echo $rhel_ver_check| grep rhel| wc -l| sed 's/ //g'` -eq 1 ] || [ "$rhel_ver_check" -gt 6 ]; then
      for file_snmp in $HOMELPAR/bin/*.pl
      do
ed $file_snmp << EOF 1>/dev/null 2>/dev/null
g/IO::Socket::INET/s/IO::Socket::INET/IO::Socket::IP/g
w
q
EOF
      done
      for file_snmp in $HOMELPAR/bin/*.pm
      do
ed $file_snmp << EOF 1>/dev/null 2>/dev/null
g/IO::Socket::INET/s/IO::Socket::INET/IO::Socket::IP/g
w
q
EOF
      done
    fi
  else
    # OS version not found, go ahead only in case of Linux
    if [ `uname -s` = "Linux" ]; then
      for file_snmp in $HOMELPAR/bin/*.pl
      do
ed $file_snmp << EOF 1>/dev/null 2>/dev/null
g/IO::Socket::INET/s/IO::Socket::INET/IO::Socket::IP/g
w
q
EOF
      done
      for file_snmp in $HOMELPAR/bin/*.pm
      do
ed $file_snmp << EOF 1>/dev/null 2>/dev/null
g/IO::Socket::INET/s/IO::Socket::INET/IO::Socket::IP/g
w
q
EOF
      done
    fi
  fi
fi

# Checking installed Perl modules
cd $HOMELPAR
# INPUTDIR must be set there mnually otherwise it is wrong "./scripts"
. $CFG; export INPUTDIR=$HOMELPAR; $PERL bin/perl_modules_check.pl $PERL
echo ""

# add unique ID of each device
# it must be behind bin/perl_modules_check.pl to use environment setup PERL5LIB (especially bin must be there)
# KZ note: run this script in each upgrade, before it was only when upgrade was from version less than 704
cd $HOMELPAR/
export INPUTDIR=$HOMELPAR # this must be defined for bin/uniqueid.pl!!!
$PERL_act bin/uniqueid.pl  > logs/uniqueid.log 2>&1
cd - >/dev/null

# DB schema update, must be behind env setup PERL5LIB
if [ -f "$HOMELPAR/data/_DB/data.db" ]; then
  for sql in `ls $HOMELPAR/dbschema/*| sort `
  do
    sql_name=`basename $sql .sql`
    if [ $sql_name -ge $VER_ORG ]; then
      echo "DB schema update: $sql"
      sqlite3 -cmd '.timeout 30000' $HOMELPAR/data/_DB/data.db < $sql
      if [ ! $? -eq 0 ]; then
        echo "SQLite DB lock perhaps, wait 5 seconds and try again"
        sleep 5
        sqlite3 -cmd '.timeout 30000' $HOMELPAR/data/_DB/data.db < $sql
      fi
    fi
  done
fi

if [ -f "$HOMELPAR/data/_DB/data.db" ]; then
  # DB init: every time, add new stuff
  sqlite3 -cmd '.timeout 30000' $HOMELPAR/data/_DB/data.db < $HOMELPAR/etc/dbinit.sql
fi

if [ $VER_ORG -lt 712 ]; then
  echo "./bin/alert_history_log_fmt.sh"
  cd $HOMELPAR
  ./bin/alert_history_log_fmt.sh
  cd - >/dev/null
fi

# just to make sure even here
rm -f $HOMELPAR/bin/tatlin* $HOMELPAR/load_tatlinperf.sh $HOMELPAR/bin/raidix* $HOMELPAR/bin/RAIDIX.pm $HOMELPAR/bin/TATLIN.pm

# Test if number of storage devices is not over the limit, env is alredy set above
over_limit=""
if [ $free_edition_new -eq 1 ]; then
  # free edition
  over_limit=`$PERL -MDeviceCfg -e 'DeviceCfg::getUnlicensed();'`
fi
if [ ! "$over_limit"x = "x" ]; then
  echo ""
  echo "*********************************"
  echo "************ WARNING ************"
  echo "You have configured more than 12 storage devices, limit of the Free edition is 12"
  echo "Consider to upgrade to the Enterprise edition: https://stor2rrd.com/support.php"
  echo "List of excluded storage devices (will not be updated anymore):"
  echo ""
  $PERL -MDeviceCfg -e 'DeviceCfg::getUnlicensed();'
  echo ""
  echo ""
  echo "************ WARNING ************"
  echo "*********************************"
  echo ""
fi

echo ""
echo "Upgrade to version $version_new is done"
echo ""
echo "Wait about 15 - 20 minutes, to get fresh data from the storages"

if [ $COLLECTOR -eq 0 ]; then
  echo ""
  echo "Then build a new GUI:"
  echo ""
  echo "  cd $HOMELPAR"
  echo "  ./load.sh 2>&1 | tee logs/load.out-initial"
  echo ""
  echo "Wait for finishing of that, then refresh the GUI (Ctrl-F5)"
  echo ""
fi


if [ $COLLECTOR -eq 0 -a "$VM_IMAGE"x = "x" -a $check -eq 1 -a $VER_ORG -lt 120 ]; then
  # not for image so far, it might be too slow
  echo ""
  echo "Checking consistency of all RRDtool DB files, it might take a few minutes in a big environment"
  echo "You can leave it running or interrupt it by Ctrl-C and start it whenever later on"
  echo "  just check out the results when it finishes"
  echo "cd $HOMELPAR; ./bin/check_rrdtool_$wlabel.sh silent"
  cd $HOMELPAR
  ./bin/check_rrdtool_stor2rrd.sh silent
  cd - >/dev/null
fi





